<?php
/*
 ______ _____   _______ _______ _______ _______ ______ _______ 
|   __ \     |_|    ___|_     _|   |   |       |   __ \   _   |
|    __/       |    ___| |   | |       |   -   |      <       |
|___|  |_______|_______| |___| |___|___|_______|___|__|___|___|

P L E T H O R A T H E M E S . C O M            (c) 2013

File Description: Features Teaser shortcode

*/

if ( ! defined( 'ABSPATH' )) exit; // NO ACCESS IF DIRECT OR TEAM POST TYPE NOT EXISTS

if ( class_exists('Plethora_Shortcode') && !class_exists('Plethora_Shortcode_FeaturesTeaser') ):

  /**
   * @package Plethora Base
   */

  class Plethora_Shortcode_FeaturesTeaser extends Plethora_Shortcode { 

    function __construct() {

          // REGISTER SHORTCODE
 
              // Hook shortcode registration on init
              $this->add('sc_featureteaser', array($this,'content'));

          // MAP PARAMETERS TO UI PANELS ( we use the params() method to get defined parameters )

              // Add shortcode parameters to shortcodes button menu.
              $this->map_panel( $this->params() );

              // Add shortcode parameters to Visual Composer UI 
              $this->map_vcpanel( $this->params() );

       }

       /** 
       * Returns feature information for several uses by Plethora Core (theme options etc.)
       *
       * @return array
       * @since 1.0
       *
       */
       public function get_feature_options() {

          $feature_options = array ( 
              'switchable'       => true,
              'options_title'    => 'Features Teaser shortcode',
              'options_subtitle' => 'Activate/deactivate Features Teaser shortcode',
              'options_desc'     => 'Add a Features Teaser Block',
            );
          
          return $feature_options;
       }

       /** 
       * Returns shortcode settings (compatible with Visual composer)
       *
       * @return array
       * @since 1.0
       *
       */
       public function params() {

          $sc_settings =  array(
              "base"              => $this->shortcode_slug,
              "name"              => __("Features Teaser", 'cleanstart'),
              "description"       => __('Add a Features Teaser Block', 'cleanstart'),
              "class"             => "",
              "weight"            => 1,
              "category"          => 'Plethora Shortcodes',
              "button_menu"       => 'Typography',    
              "admin_enqueue_css" => THEME_CORE_ASSETS_URI .'/admin-shortcodes.css',
              "icon"              => THEME_CORE_ASSETS_URI . '/icons/plethora_shortcodes-32x32.png', 
              "params"            => array(
                  array(
                      "param_name"    => "image",                                  
                      "type"          => "attach_image",                                        
                      "holder"        => "h4",                                               
                      "class"         => "vc_hidden",                                                 
                      "heading"       => __("Image", 'cleanstart'),      
                      "value"         => '',
                      "btn_menu_value"=> '', 
                      "description"   => __("Image to display", 'cleanstart'),       
                      "admin_label"   => false,                                              
                  )
                  ,array(
                      "param_name"    => "image_link",
                      "type"          => "vc_link",
                      "holder"        => "h4",
                      "class"         => "vc_hidden", 
                      "heading"       => __("Image link", 'cleanstart'),
                      "value"         => '#',
                      "btn_menu_value"=> '#', 
                      "description"   => __("Enter a link for the image.", 'cleanstart'),
                      "admin_label"   => false                                               
                 )
                  ,array(
                      "param_name"    => "title",                                  
                      "type"          => "textfield",                                        
                      "holder"        => "h4",                                               
                      "class"         => "vc_hidden",                                                 
                      "heading"       => __("Title", 'cleanstart'),
                      "value"         => 'Your Title',                                     
                      "btn_menu_value"=> 'Your Title',                                  
                      "description"   => __("Add a title (accepts html)", 'cleanstart'),      
                      "admin_label"   => false,                                             
                      'dependency'    => array( 
                                          'element' => 'columns', 
                                          'value' => array('1','2','3','4'),   
                                      )
                  )
                  ,array(
                      "param_name"    => "content",
                      "type"          => "textarea_html",
                      "holder"        => "h4",
                      "class"         => "vc_hidden",
                      "heading"       => __("Text Content", 'cleanstart'),
                      "value"         => 'Your text content here.',
                      "btn_menu_value"=> 'Your text content here.', 
                      "description"   => __("Add a description text for your price plan (accepts html)", 'cleanstart'),
                      "admin_label"   => false,                                               
                      'dependency'    => array( 
                                          'element' => 'columns',  
                                          'value' => array('1','2','3','4'),       
                                      )
                  )
              )
          );

          return $sc_settings;
       }


       /** 
       * Returns shortcode content
       *
       * @return array
       * @since 1.0
       *
       */
       public function content( $atts, $content = null ) {

        $this->add_script = true; 

          extract( shortcode_atts( array( 
            'title'         => 'CLEAN, RESPONSIVE DESIGN',
            'button_link_1' => '#',
            'image'         => '',
            'image_link'    => ''
            ), $atts ) );

          /*** GET IMAGE ALT ATTRIBUTE ***/
          $image_id   = $image; 
          $alt        = get_post_meta( $image_id, '_wp_attachment_image_alt', true );
          $alt        = ( count( $alt ) ) ? $alt : '';  
          
          $image      = (!empty($image)) ? wp_get_attachment_image_src( $image, 'full' ) : '';
          $image_link = self::vc_build_link( $image_link );

          $content = wpb_js_remove_wpautop($content, true);

          $output  = "<div class='feature_teaser'>\n";
          if ( $image !== '' ){
            if ( $image_link['url'] !== '') { $output .= '<a href="' . esc_url( $image_link['url'] ) . '" target="' . esc_attr( $image_link['target'] ) . '" title="' . esc_attr( $image_link['title'] ) . '">'; }
            $output .= "  <img alt='" . $alt . "' src='" . esc_url( $image[0] ). "'>\n";
            if ( $image_link['url'] !== '') { $output .= '</a>'; }
          }
          $output .= "  <h3>" . $title . "</h3>\n";
          $output .= $content . "\n";
          $output .= "</div>";

          return $output;

       }

  }
  
 endif;