<?php
/*
 ______ _____   _______ _______ _______ _______ ______ _______ 
|   __ \     |_|    ___|_     _|   |   |       |   __ \   _   |
|    __/       |    ___| |   | |       |   -   |      <       |
|___|  |_______|_______| |___| |___|___|_______|___|__|___|___|

P L E T H O R A T H E M E S . C O M 				   (c) 2014

Description: Inlcudes any theme-specific functionality.

*/

if ( ! defined( 'ABSPATH' ) ) exit; // NO DIRECT ACCESS 

  class Plethora_Theme { 

    static function init() {

      // ADD POST THUMBNAILS
        add_theme_support( 'post-thumbnails' );

      // ADD ADDITIONAL THUMBNAIL SIZES
        add_image_size( 'thumb-portfolio', 210, 210, true );

      // ADD POST FORMATS SUPPORT
        add_theme_support( 'post-formats', array( 'video', 'audio' ) );

      // ADD AUTOMATIC FEED LINKS SUPPORT
        add_theme_support( 'automatic-feed-links' );        

      // SET THE $content_width VARIABLE
        if ( ! isset( $content_width ) ) {  $content_width = 960; }

      // LOAD THEME'S TRANSLATED STRINGS
        add_action('after_setup_theme', array( 'Plethora_Theme', 'load_textdomain'));

      // ENQUEUE SCRIPTS AND STYLES
        add_action( 'wp_enqueue_scripts', array( 'Plethora_Theme', 'enqueue'), 1 );

      // REGISTER NAVIGATION MENUS 
        add_action( 'init', array( 'Plethora_Theme', 'register_navigation' ));

      // REGISTER SIDEBARS
        self::register_sidebars();

      // FILTER BODY CLASS ( just remove sticky_header class )  
        add_filter('body_class', array('Plethora_Theme', 'body_class'));

      // CONVERT MENU ITEM 'CSS CLASS' INPUT INTO SELECT FIELD ( ON APPEARENCE > MENUS )
        add_action('admin_footer', array('Plethora_Theme', 'menu_item_classes')); 

      // PLACE CUSTOM JS ON FOOTER ( depending on theme settings )
        add_action('wp_footer', array('Plethora_Theme', 'set_custom_js'), 20); 

      // PLACE CUSTOM CSS ON HEAD ( depending on theme settings )
        add_action('wp_head', array('Plethora_Theme', 'set_custom_css'), 999); 

      // LOAD CUSTOM VC TEMPLATES
      add_action('vc_load_default_templates_action', array( 'Plethora_Theme', 'load_custom_templates' ) );

      // DEQUEUE ace.js EDITOR USED BY REDUX
      add_action( 'admin_enqueue_scripts', array( 'Plethora_Theme', 'cleanstart_dequeue_script' ), 100 );

      // FIX oEMBEDS W3C VALIDATION
      add_filter('oembed_dataparse', array( 'Plethora_Theme', 'soundcloud_oembed_filter'), 90, 3 );

      // FIX CONTACT FORM 7 DEFAULT MARKUP AND STYLING
      add_filter( 'wpcf7_form_elements', array('Plethora_Theme', 'cleanstart_wpcf7_form_elements') );

    }

    /**
    * Fix Contact Form 7 default markup and styling
    *
    * @since 1.0
    *
    */
    static function cleanstart_wpcf7_form_elements( $content ) {
      // global $wpcf7_contact_form;

      $content = preg_replace( "/wpcf7-text/", "wpcf7-form-control form-control", $content );
      $content = preg_replace( "/wpcf7-email/", "wpcf7-form-control form-control", $content );
      $content = preg_replace( "/form-controlarea/", "wpcf7-form-control form-control", $content );
      $content = preg_replace( "/wpcf7-submit/", "wpcf7-submit btn btn-primary", $content );
      return $content;  
    }
 
    /**
     * Fix oEmbed W3C validation issues
     *
     * @since 1.0
     *
     */
    static function soundcloud_oembed_filter( $return, $data, $url ) {

      $style = '';

      if ( strpos($return, 'frameborder="0"') !== FALSE ){
        $style .= 'border:none;';
        $return = str_replace('frameborder="0"', '', $return);
      } elseif ( strpos($return, 'frameborder="no"') !== FALSE ) {
        $style .= 'border:none;';
        $return = str_replace('frameborder="no"', '', $return);
      }

      if ( strpos($return, 'scrolling="no"') !== FALSE ){
        $style .= 'overflow:hidden;';
        $return = str_replace('scrolling="no"', 'style="'.$style.'"', $return);
      } else {
        $return = str_replace('<iframe', '<iframe style="'.$style.'"', $return);
      }

      return $return;
    }


    /**
     * Dequeue ace.js editor from post/page editor to avoid conflicts with VC ace.js editor
     *
     * @param 
     * @return 
     * @since 1.0
     *
     */
    static function cleanstart_dequeue_script( $hook ) {
      if ( 'toplevel_page_cleanstart_options' == $hook ) { return; }
      wp_dequeue_script( 'ace-editor-js' );
      wp_dequeue_script( 'redux-field-ace-editor-js' );
      wp_dequeue_style( 'redux-field-ace-editor-css' );
    }


    /**
     * Load theme's translated strings
     *
     * @param 
     * @return 
     * @since 1.0
     *
     */
    static function load_textdomain() { 

        global $locale;
        load_textdomain( THEME_TXTDOMAIN, get_template_directory() . '/languages/'. $locale .'.mo' );

    }

    /**
     * Enqueue Scripts and Styles
     *
     * @param 
     * @return 
     * @since 1.0
     *
     */
    static function enqueue() {

    //  Registering MANDATORY theme SCRIPTS / STYLES
            //scripts
            wp_register_script ( 'modernizr',           THEME_ASSETS_URI . '/js/modernizr.custom.48287.js',            array(),            '', FALSE ); // ok
            wp_register_script ( 'boostrap',            THEME_ASSETS_URI . '/twitter-bootstrap/js/bootstrap.min.js',   array( 'jquery' ),  '', TRUE ); // ok
            wp_register_script ( 'easing',              THEME_ASSETS_URI . '/js/easing.js',                            array( 'jquery' ),  '', TRUE ); // ok
            wp_register_script ( 'wow',                 THEME_ASSETS_URI . '/js/wow.min.js',                           array( 'jquery' ),  '', TRUE ); // ok
            wp_register_script ( 'simple-text-rotator', THEME_ASSETS_URI . '/js/jquery.simple-text-rotator.js',        array( 'jquery' ),  '', TRUE ); // ok
            wp_register_script ( 'cleanstart',          THEME_ASSETS_URI . '/cleanstart_theme.js',                     array( 'jquery' ),  '', TRUE ); // ok
            wp_register_script ( 'collapser',           THEME_ASSETS_URI . '/js/collapser.js',                         array( 'jquery' ),  '', TRUE ); // ok
            wp_register_script ( 'flexslider-cleanstart',          THEME_ASSETS_URI . '/js/flexslider/jquery.flexslider-min.js',  array( 'jquery' ),  '', TRUE ); // ok

            wp_enqueue_script( 'modernizr' );
            wp_enqueue_script( 'boostrap' );
            wp_enqueue_script( 'easing' );
            wp_enqueue_script( 'wow' );
            wp_enqueue_script( 'simple-text-rotator' );

           //styles
            wp_register_style( 'animate-css',          THEME_ASSETS_URI . '/css/animate.css' ); 
            wp_register_style( 'mainmenu-css',         THEME_ASSETS_URI . '/css/mainmenu.css' ); 
            wp_register_style( 'fontawesome',          THEME_ASSETS_URI . '/fonts/font-awesome-4/css/font-awesome.min.css' ); 
            wp_register_style( 'simple-text-rotator',  THEME_ASSETS_URI . '/css/simpletextrotator.css' ); 
            wp_register_style( 'flexslider-cleanstart',           THEME_ASSETS_URI . '/js/flexslider/flexslider.css' ); 

            wp_enqueue_style( 'animate-css' );
            wp_enqueue_style( 'bootstrap' );
            wp_enqueue_style( 'mainmenu-css' );
            wp_enqueue_style( 'fontawesome' );
            wp_enqueue_style( 'simple-text-rotator' );
            wp_enqueue_style( 'flexslider-cleanstart' );  

    //  OPTIONAL SCRIPTS / STYLES ( loaded selectively )

         // Back to top button
        $backtotop   = self::option( 'backtotop-status', 1, 0, false);
        if ( $backtotop == 1 ) { 

            wp_register_script( 'backtotop', THEME_ASSETS_URI . '/js/jquery.ui.totop.js', 'jquery', '', TRUE); 
            wp_enqueue_script( 'backtotop' ); 
        }

        // Twitter Feed Script
        $twitterfeed   = self::option( PLETHORA_META_PREFIX .'footer-twitterfeed', 1, 0, false);
        if ( $twitterfeed == 1 ) {
            wp_register_script( 'twitter_feed', THEME_ASSETS_URI . '/cleanstart_twitterfeedslider.js', array('jquery','flexslider-cleanstart'), '', TRUE); 
            wp_enqueue_script( 'twitter_feed' ); 
        }

        // Portfolio single view // Slider
        if ( is_single() && get_post_type() == 'portfolio' ) { 
            
            wp_register_script('imagelightbox-plethora',  THEME_ASSETS_URI . '/js/imagelightbox.min.js',  array( 'jquery' ),  '', TRUE ); 
            wp_enqueue_script( 'imagelightbox-plethora');
            wp_register_style( 'imagelightbox-plethora',  THEME_ASSETS_URI . '/js/flexslider/flexslider.css' ); 
            wp_enqueue_style(  'imagelightbox-plethora');


            wp_enqueue_script('flexslider-cleanstart');
            wp_enqueue_style( 'flexslider-cleanstart' );

            //inits
            wp_register_script ( 'portfolio-slider',  THEME_ASSETS_URI . '/cleanstart_portfolioslider.js',  array('flexslider-cleanstart'),  '', TRUE ); // OK

        }
 
            wp_enqueue_script( 'cleanstart' );
            wp_enqueue_script  ( 'portfolio-slider' );
            wp_enqueue_script( 'collapser' );

    }

    /**
     * Adds custom JS script to footer
     *
     * @param
     * @return string
     *
     */
    static function set_custom_js() {

      $custom_js = self::option('custom-js');

      if ( !empty( $custom_js ) ) { 

          $html  = "\n<script type=\"text/javascript\">\n";
          $html .= trim($custom_js) ."\n"; 
          $html .= "</script>\n";
        
        echo $html;

      } 
    }    

    /**
     * Adds custom CSS style field to footer
     *
     * @param 
     * @return string
     *
     */
    static function set_custom_css() {

      $custom_css = self::option('custom-css');

      if ( !empty( $custom_css ) ) { 

          $html  = "\n<style>\n";
          $html .= trim($custom_css) ."\n"; 
          $html .= "</style>\n";
        
        echo $html;

      } 
    }    
    /**
     * Register Navigation Menu
     *
     * @param 
     * @return 
     * @since 1.0
     *
     */
    static function register_navigation() {

      register_nav_menu( 'primary', __( 'Primary Navigation', 'cleanstart') );
      register_nav_menu( 'toolbar', __( 'Top Header Navigation', 'cleanstart') );

    }

    /**
     * Register Sidebars. 
     *
     * @param 
     * @return 
     * @since 1.0
     *
     */
    static function register_sidebars() {

      $footer_layout   = self::option( 'footer-layout', 5, 0, false);

      switch ( $footer_layout ) {
        case '1':
          $footer_classes = array( 'col1' => 'col-sm-12 col-md-12', 'col2' => 'hide', 'col3' => 'hide', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          $sidebar3_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;

        case '2':
          $footer_classes = array( 'col1' => 'col-sm-6 col-md-6', 'col2' => 'col-sm-6 col-md-6', 'col3' => 'hide', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;

        case '3':
          $footer_classes = array( 'col1' => 'col-sm-8 col-md-8', 'col2' => 'col-sm-4 col-md-4', 'col3' => 'hide', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;

        case '4':
          $footer_classes = array( 'col1' => 'col-sm-4 col-md-4', 'col2' => 'col-sm-8 col-md-8', 'col3' => 'hide', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;

        case '5':
          $footer_classes = array( 'col1' => 'col-sm-4 col-md-4', 'col2' => 'col-sm-4 col-md-4', 'col3' => 'col-sm-4 col-md-4', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'Footer Widget Area | Column 3', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;

        case '6':
          $footer_classes = array( 'col1' => 'col-sm-3 col-md-3', 'col2' => 'col-sm-3 col-md-3', 'col3' => 'col-sm-6 col-md-6', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'Footer Widget Area | Column 3', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;

        case '7':
          $footer_classes = array( 'col1' => 'col-sm-6 col-md-6', 'col2' => 'col-sm-3 col-md-3', 'col3' => 'col-sm-3 col-md-3', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'Footer Widget Area | Column 3', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;

        case '8':
          $footer_classes = array( 'col1' => 'col-sm-3 col-md-3', 'col2' => 'col-sm-3 col-md-3', 'col3' => 'col-sm-3 col-md-3', 'col4' => 'col-sm-3 col-md-3' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'Footer Widget Area | Column 3', 'cleanstart' );
          $sidebar4_desc = __( 'Footer Widget Area | Column 4', 'cleanstart' );
          break;

        default:
          $footer_classes = array( 'col1' => 'col-sm-4 col-md-4', 'col2' => 'col-sm-4 col-md-4', 'col3' => 'col-sm-4 col-md-4', 'col4' => 'hide' );
          $sidebar1_desc = __( 'Footer Widget Area | Column 1', 'cleanstart' );
          $sidebar2_desc = __( 'Footer Widget Area | Column 2', 'cleanstart' );
          $sidebar3_desc = __( 'Footer Widget Area | Column 3', 'cleanstart' );
          $sidebar4_desc = __( 'This widget area is inactive. You may activate this area on CleanStart > Header', 'cleanstart' );
          break;
      }

     $sidebar_default = array(
        'name'          => __( 'Blog Sidebar', 'cleanstart' ),
        'id'            => 'sidebar-default',
        'class'         => '',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4>',
        'after_title'   => '</h4>' ); 

     $sidebar_pages = array(
        'name'          => __( 'Pages Sidebar', 'cleanstart' ),
        'id'            => 'sidebar-pages',
        'class'         => '',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget'  => '</aside>',
        'before_title'  => '<h4>',
        'after_title'   => '</h4>' ); 

     $sidebar_footer_one = array(
        'name'          => __( 'Footer Column #1', 'cleanstart' ),
        'id'            => 'sidebar-footer-one',
        'description'   => $sidebar1_desc,
          'class'         => '',
        'before_widget' => '<div id="%1$s" class="widget %2$s ' . $footer_classes['col1'] . '">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>' ); 

      $sidebar_footer_two = array(
        'name'          => __( 'Footer Column #2', 'cleanstart' ),
        'id'            => 'sidebar-footer-two',
        'description'   => $sidebar2_desc,
          'class'         => '',
        'before_widget' => '<div id="%1$s" class="widget %2$s ' . $footer_classes['col2'] . '">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>' ); 

      $sidebar_footer_three = array(
        'name'          => __( 'Footer Column #3', 'cleanstart' ),
        'id'            => 'sidebar-footer-three',
        'description'   => $sidebar3_desc,
          'class'         => '',
        'before_widget' => '<div id="%1$s" class="widget %2$s ' . $footer_classes['col3'] . '">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>' ); 

      $sidebar_footer_four = array(
        'name'          => __( 'Footer Column #4', 'cleanstart' ),
        'id'            => 'sidebar-footer-four',
        'description'   => $sidebar4_desc,
          'class'         => '',
        'before_widget' => '<div id="%1$s" class="widget %2$s ' . $footer_classes['col4'] . '">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3>',
        'after_title'   => '</h3>' ); 


      register_sidebar( $sidebar_default ); 
      register_sidebar( $sidebar_pages ); 
      register_sidebar( $sidebar_footer_one ); 
      register_sidebar( $sidebar_footer_two ); 
      register_sidebar( $sidebar_footer_three ); 
      register_sidebar( $sidebar_footer_four );       

      $sidebars   = self::option( 'sidebars-number', 0, 0, false);
      for ($x=1; $x<=$sidebars; $x++) {

          $sidebar = array(
              'name'          => __( 'Sidebar #', 'cleanstart' ) . $x ,
              'id'            => 'sidebar-'. $x .'',
              'description'   => __('This is a custom bar, created using Theme Settings panel','cleanstart'),
                'class'         => '',
              'before_widget' => '<aside id="%1$s" class="widget %2$s">',
              'after_widget'  => '</aside>',
              'before_title'  => '<h4>',
              'after_title'   => '</h4>' );  
          register_sidebar( $sidebar ); 
      }

    }

    /**
     * Enqueue a JS hack that converts CSS classes input to select on menu items ( Appearence > Menus )
     *
     * @param 
     * @return
     * @since 1.0
     *
     */

    static function menu_item_classes(){
        global $pagenow;
        if ($pagenow == "nav-menus.php") {
            wp_register_script('menuitem-plethora',  THEME_ASSETS_URI . '/js/menu_class_input_to_select.js',  array( 'jquery' ),  '', TRUE ); // ok
            wp_enqueue_script( 'menuitem-plethora');
        }
    }

    /**
     * A filter for body_class, when menu is not sticky
     *
     * @param 
     * @return number / string ('nonstatic', '404page')
     * @since 1.0
     *
     */

    static function body_class( $classes ) { 

      $header_sticky = self::option( PLETHORA_META_PREFIX .'header-sticky', 1, 0, false);

      if ( $header_sticky == 0) { 

        $classes = str_replace( 'sticky_header', '', $classes);  // Just removed sticky_header class;

      }
      return $classes;

    }


    /**
     * Returns current page's postid, even if it is a blog page...if page is fphp
     *
     * @param 
     * @return number / string ('nonstatic', '404page')
     * @since 1.0
     *
     */

    static function get_the_id() {

      if ( ( is_front_page() && is_home() ))  { // This is not a desired output...users should select static pages for home/blog 

        $return = 'nonstatic';

      } elseif (  is_404() ) { 

        $return = '404page';

      } elseif ( is_home() || is_search() || is_archive() || is_tag() || is_author() || is_date() ) { 

        $return = get_option('page_for_posts');

      } else { 

        $return = get_queried_object_id();
      
      }           

      return $return;
      

    }      

    /**
     * Handles developer comments according to theme settings
     *
     * @param $comment, $commentgroup
     * @return string
     * @since 1.0
     *
     */

    static function dev_comment( $comment = '', $commentgroup = '' ) {

      if ( !is_admin() && !is_feed() && current_user_can('manage_options') ) { 
      
        global $cleanstart_options; // Get theme options

        $commentgroup_status = isset( $cleanstart_options['dev-comments-'. $commentgroup .''] ) ? $cleanstart_options['dev-comments-'. $commentgroup .''] : 'disable';

        if ( $commentgroup_status == 'enable' && !empty( $comment ) ) { 

            print_r( "\n".'<!-- '. $comment .'  -->'."\n" );

        }
      }

    }

    static function page_dev_comment() { 

      if ( is_front_page() && is_home() ) {

          return 'This is the default \'Your latest posts\' front page. You should change this, by selecting a static page for Front Page / Posts Page on Reading settings';

      } elseif ( is_front_page() ) {

          return 'This is a Static Front Page you selected on Reading Settings. You may edit this page by clicking \'Edit page\' on your admin bar';

      } elseif ( is_home() ) {

          return 'This is a Static Posts Page ( Blog ) you selected on Reading Settings. You may affect this page look, using the \'Cleanstart Settings > Blog\' options panel.';

      } elseif ( is_search() ) {

          return 'This is a Search Page. You may affect this page look, using the \'Cleanstart Settings > Blog\' options panel';

      } elseif ( is_404() ) {

          return 'This is a 404 Page. You may affect this page look, using the \'Cleanstart Settings > 404 Page\' options panel';

      } else {
       
          if ( is_page() ) { 

          return 'This is a single Page. You may edit this page by clicking \'Edit page\' on your admin bar.';

          } elseif ( is_single() ) {

          return 'This is a single '. ucfirst( get_post_type() ) .' page. You may edit this page by clicking \'Edit '. ucfirst( get_post_type() ) .'\' on your admin bar ' ;

          } elseif ( is_archive() ) {

            if ( is_category() ) {
              return 'This is an archive CATEGORY page for'. ucfirst( get_post_type() ) .'s. You may affect this page look, using the \'Cleanstart Settings > Blog\' options panel.' ;

            } elseif ( is_tag() ) {
              return 'This is an archive TAG page for '. ucfirst( get_post_type() ) .'s. You may affect this page look, using the \'Cleanstart Settings > Blog\' options panel.' ;

            } elseif ( is_tax() ) {
              return 'This is an archive CUSTOM TAXONOMY page for '. ucfirst( get_post_type() ) .'s. You may affect this page look, using the \'Cleanstart Settings > Blog\' options panel.' ;

            } elseif ( is_date() ) {
              return 'This is an archive DATE-BASED page for '. ucfirst( get_post_type() ) .'s. You may affect this page look, using the \'Cleanstart Settings > Blog\' options panel.' ;

            } else { 
              return 'This is an archive page for '. ucfirst( get_post_type() ) .'s. You may affect this page look, using the \'Cleanstart Settings > Blog\' options panel.' ;
            }

          }
      }

    }


    /**
     * This is a method for displaying post/pages override options. Checks post meta, if nothing found uses the default option
     * $postid should be given on call, when we need to get other posts info (e.g. inside posts page loop). Otherwise, is not necessary!
     *
     * @param $option_id, $user_value, $postid, $comment
     * @return string/array/bool
     * @since 1.0
     *
     */

    static function option( $option_id, $user_value = '', $postid = 0, $comment = true ) {

      // if no postid is given, use get_the_ID(). 
      if ($postid == 0) { 

          $postid = self::get_the_id();

      } 

      // If $postid is a number, then search first if post has saved a value for this option on its metaboxes
      if ( is_numeric( $postid ))  {  

        $post_option_val = get_post_meta( $postid, $option_id, true );
      
      } else { 

        $post_option_val = '';

      }

      // If nothing is found on this post meta, then check theme defaults for this option, otherwise use value that set on option call
      if ( ( is_array($post_option_val) && empty($post_option_val) ) || ( !is_array($post_option_val) && $post_option_val == '' )) { 

          $theme_options = get_option( THEME_OPTVAR ); // Use this please...NOT SAFE TO USE the global option
          $theme_option_val = ( isset( $theme_options[$option_id] )) ? $theme_options[$option_id] : $user_value;
          $source = ( isset( $theme_options[$option_id] )) ? 'Theme options value' : 'Attention...option id was not found, value given on option call';
          $option_val = $theme_option_val;

      } else { 

        $option_val = $post_option_val;
        $source = 'Post meta value';

      }
      
      // Produce a comment
      if ( is_array( $option_val )) { $comment_option_val = json_encode($option_val); } else { $comment_option_val = $option_val; }

      if ( $comment == true ) { 
        Plethora_Theme::dev_comment('Option called (postid|option|value|info): '. $postid .' | '. $option_id .' | '. $comment_option_val .' | '. $source .'', 'options');
      }
      // Return the value
      return $option_val;

    }
    /**
     * Returns slider options array
     *
     * @param $sliderid
     * @return array
     * @since 1.0
     *
     */
    static function get_slider_options( $sliderid ) {

        $slider_options = array();

        if ( $sliderid > 0 ) { 

          $slider_options['slideshow']      = self::option( PLETHORA_META_PREFIX . 'slider-slideshow', 'true', $sliderid );
          $slider_options['direction']      = self::option( PLETHORA_META_PREFIX . 'slider-direction', 'vertical', $sliderid );
          $slider_options['animationloop']  = self::option( PLETHORA_META_PREFIX . 'slider-animationloop', 'true', $sliderid );
          $slider_options['slideshowspeed'] = self::option( PLETHORA_META_PREFIX . 'slider-slideshowspeed', '10', $sliderid );
          $slider_options['animationspeed'] = self::option( PLETHORA_META_PREFIX . 'slider-animationspeed', '600', $sliderid );
          $slider_options['showarrows']     = self::option( PLETHORA_META_PREFIX . 'slider-showarrows', 'true', $sliderid );
          $slider_options['showbullets']    = self::option( PLETHORA_META_PREFIX . 'slider-showbullets', 'true', $sliderid );
          $slider_options['randomize']      = self::option( PLETHORA_META_PREFIX . 'slider-randomize', 'false', $sliderid );
          $slider_options['pauseonaction']  = self::option( PLETHORA_META_PREFIX . 'slider-pauseonaction', 'true', $sliderid );
          $slider_options['pauseonhover']   = self::option( PLETHORA_META_PREFIX . 'slider-pauseonhover', 'true', $sliderid );

        }

        return $slider_options;
    }

    /**
     * Returns html that should be rendered before wp_head
     *
     * @param
     * @return string
     *
     */
    static function html_pre_wphead() {

      $icon_retina114 = self::option( 'icon-retina114', array());
      $icon_retina72  = self::option( 'icon-retina72', array());
      $icon_retina57  = self::option( 'icon-retina57', array());
      $icon_favicon   = self::option( 'favicon', array());

      /* ADD FAVICONS: Upload 200x200 Image and create all versions from that image.
      /*
      <link rel="apple-touch-icon" sizes="57x57" href="/apple-touch-icon-57x57.png">
      <link rel="apple-touch-icon" sizes="114x114" href="/apple-touch-icon-114x114.png">
      <link rel="apple-touch-icon" sizes="72x72" href="/apple-touch-icon-72x72.png">
      <link rel="apple-touch-icon" sizes="60x60" href="/apple-touch-icon-60x60.png">
      <link rel="apple-touch-icon" sizes="120x120" href="/apple-touch-icon-120x120.png">
      <link rel="apple-touch-icon" sizes="76x76" href="/apple-touch-icon-76x76.png">
      <link rel="icon" type="image/png" href="/favicon-96x96.png" sizes="96x96">
      <link rel="icon" type="image/png" href="/favicon-16x16.png" sizes="16x16">
      <link rel="icon" type="image/png" href="/favicon-32x32.png" sizes="32x32">
      <meta name="msapplication-TileColor" content="#da532c">
      */

      $html  = '<meta name="apple-mobile-web-app-capable" content="yes">'."\n";
      $html .= '<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />'."\n";
      $html .= '<meta name="HandheldFriendly" content="true" />'."\n";
      $html .= '<meta name="apple-touch-fullscreen" content="yes" />'."\n";
      if ( isset( $icon_retina114['url'] ) && !empty( $icon_retina114['url'] )) { 
          $html .= '<link rel="apple-touch-icon-precomposed" sizes="114x114" href="'. esc_url( $icon_retina114['url'] ) .'">'."\n";
      } 
      if ( isset( $icon_retina72['url'] ) && !empty( $icon_retina72['url'] )) {
          $html .= '<link rel="apple-touch-icon-precomposed" sizes="72x72" href="'. esc_url( $icon_retina72['url'] ) .'">'."\n";
      }
      if ( isset( $icon_retina57['url'] ) && !empty( $icon_retina57['url'] )) { 
          $html .= '<link rel="apple-touch-icon-precomposed" href="'. esc_url( $icon_retina57['url'] ) .'">'."\n";
      }
      if ( isset( $icon_favicon['url'] ) && !empty( $icon_favicon['url'] )) {
          $html .= '<link rel="shortcut icon" href="'. esc_url( $icon_favicon['url'] ) .'">'."\n";
      } 
        return $html;
    }

    /**
     * Returns analytics script
     *
     * @param $position ( header, footer )
     * @return string
     *
     */
    static function html_analytics( $position ) {

      if ( empty($position) ) { return; }

      $analytics_code           = self::option('analytics-code');
      $analytics_code_placement = self::option('analytics-code-placement');

      if ( !empty( $analytics_code ) && $analytics_code_placement ===  $position ) { 

          $html  = "\n<script type='text/javascript'>\n";
          $html .= trim($analytics_code) ."\n"; 
          $html .= "</script>\n";
        
        return $html;

      } 
    }    

    /**
     * Returns top toolbar template_part
     *
     * @param 
     * @return null
     *
     */
    static function html_toolbar() {

      $header_toolbar        = self::option( PLETHORA_META_PREFIX .'header-toolbar');

      if ( $header_toolbar == 1 ) { 

            get_template_part('includes/partials/element', 'toolbar' );

      }         
    }    

    /**
     * Returns main navigation template_part
     *
     * @param 
     * @return null
     *
     */
    static function html_navigation() {

      get_template_part('includes/partials/element', 'navigation-main');
    
    }    

    /**
     * Returns featured media template_part
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia() {
      
      // There is a different treat of featured media section for each of the following cases
      if ( is_404() ) { 

        get_template_part('includes/partials/headermedia', '404');

      } else { 

        $page_featuredmedia = self::option( PLETHORA_META_PREFIX .'header-media', 'nomedia');
        get_template_part('includes/partials/headermedia', strtolower( $page_featuredmedia ));
      
      }
    }    

    /**
     * Returns header media title
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_title() {
      
      $html = '';

      if ( is_front_page() && is_home() ) { 

          $blog_header_title  = self::option( 'blog-header-title');         
          $title = ( !empty( $blog_header_title )) ? $blog_header_title : '';
     
      } elseif ( is_home() ) { 

          $blog_header_title        = self::option( 'blog-header-title');         
          $title = ( !empty( $blog_header_title )) ? $blog_header_title : '';
     
      } elseif ( is_search() ) { 

          $blog_header_title_search = self::option( 'blog-header-title-search');         
          $title_prfx = ( !empty( $blog_header_title_search )) ? $blog_header_title_search : '';
          $title =  $title_prfx . get_search_query();

      } elseif ( is_404() ) { 

          $four04_header_title = self::option( '404-header-title');         
          $title = ( !empty( $four04_header_title )) ? $four04_header_title : '';

      } elseif ( is_archive() ) { 
      
            if ( is_category() ) { //ok
              
              $blog_header_title_cat    = self::option( 'blog-header-title-cat');         
              $title_prfx = ( !empty( $blog_header_title_cat )) ? $blog_header_title_cat : '';
              $title = single_cat_title($title_prfx, false);

            } elseif ( is_tag() ) { //ok
              
              $blog_header_title_tag    = self::option( 'blog-header-title-tag');         
              $title_prfx = ( !empty( $blog_header_title_tag )) ? $blog_header_title_tag : '';
              $title = single_cat_title($title_prfx, false);

            } elseif ( is_author() ) { //ok
              
              $blog_header_title_author = self::option( 'blog-header-title-author');         
              $title_prfx = ( !empty( $blog_header_title_author )) ? $blog_header_title_author : '';
              $title =  $title_prfx . get_the_author();

            } elseif ( is_date() ) {//ok
              
              $blog_header_title_date   = self::option( 'blog-header-title-date');         
              $title_prfx = ( !empty( $blog_header_title_date )) ? $blog_header_title_date : '';
              $title =  $title_prfx . single_month_title('', false ) ;
            }

      } else { 
         
          $post_type = get_post_type();
          $title_behavior           = self::option( PLETHORA_META_PREFIX . 'header-title-type-'. $post_type .'', 'blogtitle');
          if ( $title_behavior == 'posttitle' ) { 

            $title = get_the_title();

          } elseif ( $title_behavior == 'customtitle' ) {
          
            $title   = self::option( PLETHORA_META_PREFIX . 'header-customtitle-'. $post_type .'', '');

          } elseif ( $title_behavior == 'blogtitle' ) {

            $blog_title   = self::option( 'blog-header-title');
            $title = ( !empty( $blog_title )) ? $blog_title : '';

          } elseif ( $title_behavior == 'notitle' ) {

            $title = '';

          }
      }


      if ( !empty( $title )) { 

        $html  .= '<div class="hgroup_title animated bounceInUp">'."\n";
        $html  .= '   <div class="container">'."\n";
        $html  .= '     <h1>'. $title .'</h1>'."\n";
        $html  .= '   </div>'."\n";
        $html  .= '</div>'."\n";

      } 

      return $html;
    } 

    /**
     * Returns header media subtitle
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_subtitle() {

      $html = '';

      if ( is_front_page() && is_home() ) { 

          $blog_header_subtitle = self::option( 'blog-header-subtitle');         
          $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
     
      } elseif ( is_home() ) { 

          $blog_header_subtitle = self::option( 'blog-header-subtitle');         
          $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
     
      } elseif ( is_search() ) { 

              $blog_header_subtitle_search  = self::option( 'blog-header-subtitle-search');

              $subtitle_type = ( !empty( $blog_header_subtitle_search )) ? $blog_header_subtitle_search : '';
              switch ( $subtitle_type ) {
                  
                  case 'nosubtitle' :
                    $subtitle = '';
                    break;

                  case 'usedefault' :
                    $blog_header_subtitle = self::option( 'blog-header-subtitle');         
                    $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
                    break;

                  case 'usecustom' :
                    $blog_header_subtitle_search_custom = self::option( 'blog-header-subtitle-search-custom');         
                    $subtitle = ( !empty( $blog_header_subtitle_search_custom )) ? $blog_header_subtitle_search_custom : '';
                    break;
              }


      } elseif ( is_404() ) { 

          $four04_header_subtitle = self::option( '404-header-subtitle');         
          $subtitle = ( !empty( $four04_header_subtitle )) ? $four04_header_subtitle : '';


      } elseif ( is_archive() ) { 
      
            if ( is_category() ) { 

              $blog_header_subtitle_cat = self::option( 'blog-header-subtitle-cat');         

              $subtitle_type = ( !empty( $blog_header_subtitle_cat )) ? $blog_header_subtitle_cat : '';
              switch ( $subtitle_type ) {
                  
                  case 'nosubtitle' :
                    $subtitle = '';
                    break;

                  case 'usedefault' :
                    $blog_header_subtitle     = self::option( 'blog-header-subtitle');         
                    $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
                    break;

                  case 'usedescription' :
                    $subtitle = category_description();
                    break;

                  case 'usecustom' :
                   $blog_header_subtitle_cat_custom  = self::option( 'blog-header-subtitle-cat-custom');
                   $subtitle = ( !empty( $blog_header_subtitle_cat_custom )) ? $blog_header_subtitle_cat_custom : '';
                    break;
              }


            } elseif ( is_tag() ) {

              $blog_header_subtitle_tag         = self::option( 'blog-header-subtitle-tag');         

              $subtitle_type = ( !empty( $blog_header_subtitle_tag )) ? $blog_header_subtitle_tag : '';
              switch ( $subtitle_type ) {
                  
                  case 'nosubtitle' :
                    $subtitle = '';
                    break;

                  case 'usedefault' :
                    $blog_header_subtitle     = self::option( 'blog-header-subtitle');         
                    $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
                    break;

                  case 'usedescription' :
                    $subtitle = tag_description();
                    break;

                  case 'usecustom' :
                   $blog_header_subtitle_tag_custom  = self::option( 'blog-header-subtitle-tag-custom');
                   $subtitle = ( !empty( $blog_header_subtitle_tag_custom )) ? $blog_header_subtitle_tag_custom : '';
                    break;
              }

              
            } elseif ( is_author() ) {

              $blog_header_subtitle_author        = self::option( 'blog-header-subtitle-author');         

              $subtitle_type = ( !empty( $blog_header_subtitle_author )) ? $blog_header_subtitle_author : '';
              switch ( $subtitle_type ) {
                  
                  case 'nosubtitle' :
                    $subtitle = '';
                    break;

                  case 'usedefault' :
                    $blog_header_subtitle = self::option( 'blog-header-subtitle');         
                    $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
                    break;

                  case 'usebio' :
                    $subtitle = get_the_author_meta('description');
                    break;

                  case 'usecustom' :
                    $blog_header_subtitle_author_custom = self::option( 'blog-header-subtitle-author-custom');   
                    $subtitle = ( !empty( $blog_header_subtitle_author_custom )) ? $blog_header_subtitle_author_custom : '';
                    break;
              }
              
            } elseif ( is_date() ) {

              $blog_header_subtitle_date  = self::option( 'blog-header-subtitle-date');         
              $subtitle_type = ( !empty( $blog_header_subtitle_date )) ? $blog_header_subtitle_date : '';
              switch ( $subtitle_type ) {
                  
                  case 'nosubtitle' :
                    $subtitle = '';
                    break;

                  case 'usedefault' :
                    $blog_header_subtitle       = self::option( 'blog-header-subtitle');         
                    $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
                    break;

                  case 'usecustom' :
                    $blog_header_subtitle_date_custom = self::option( 'blog-header-subtitle-date-custom');         
                    $subtitle = ( !empty( $blog_header_subtitle_date_custom )) ? $blog_header_subtitle_date_custom : '';
                    break;
              }
            }

      } else { 

          $post_type = get_post_type();
          $title_behavior           = self::option( PLETHORA_META_PREFIX . 'header-title-type-'. $post_type .'', 'blogtitle');

          if ( $title_behavior == 'posttitle' ) { 

            $subtitle   = self::option( PLETHORA_META_PREFIX . 'header-customsubtitle-'. $post_type .'', '');

          } elseif ( $title_behavior == 'customtitle' ) {
          
            $subtitle   = self::option( PLETHORA_META_PREFIX . 'header-customsubtitle-'. $post_type .'', '');

          } elseif ( $title_behavior == 'blogtitle' ) {

            $blog_header_subtitle       = self::option( 'blog-header-subtitle');         
            $subtitle = ( !empty( $blog_header_subtitle )) ? $blog_header_subtitle : '';
          }
      }

      if ( !empty( $subtitle )) { 

          $html  = '<div class="hgroup_subtitle animated bounceInUp skincolored">'."\n";
          $html  .= '   <div class="container">'."\n";
          $html  .= '     <p>'. $subtitle .'</p>'."\n";
          $html  .= '   </div>'."\n";
          $html  .= '</div>'."\n";

      } 

      return $html;
    } 

    /**
     * Loads custom VC templates
     *
     * @param 
     * @return string
     *
     */
    static function load_custom_templates() {

      /** Home Page Template */

      $data                  = array();
      $data['name']          = __( 'Home Page', 'cleanstart' );
      $data['image_path']    = preg_replace( '/\s/', '%20', get_template_directory_uri() . '/assets/images/vc_template_home.jpg' ); 
      $data['custom_class']  = 'custom_template_for_vc_custom_template';
      $data['content']       = '[vc_row][vc_column width="1/3" border="right" border_width="1" color="#cccccc"][sc_featureteaser image="37" border_line="Right" title="CLEAN, RESPONSIVE DESIGN" text_content="A multipurpose but mainly business oriented design, built to serve as a foundation for your web projects. Suspendisse nec risus fermentum sapien congue fermentum sed at lorem." image="37" image_link="#"]A multipurpose but mainly business oriented design, built to serve as a foundation for your web projects. The post-flat approach in UI will add uniqueness to your project.[/sc_featureteaser][/vc_column][vc_column width="1/3" border="right" border_width="1" color="#cccccc"][sc_featureteaser image="35" border_line="Right" title="BASED ON TWITTER BOOTSTRAP" text_content="The front-end development framework with a steep learning curve. It changes the way you develop sites. Suspendisse nec risus fermentum sapien congue fermentum sed at lorem." image="35" image_link="#"]<span style="color: #666666;">The front-end development framework with a steep learning curve. Cleanstart comes with a style.less file that tries to use all the power of {less} and bootstrap combined.</span>[/sc_featureteaser][/vc_column][vc_column width="1/3"][sc_featureteaser image="36" border_line="None" title="Visual Composer Integration" text_content="Cleanstart comes with a style.less file that tries to use all the power of {less} and bootstrap combined. Suspendisse nec risus fermentum sapien congue fermentum sed at lorem." image="36" image_link="#"]<span style="color: #666666;">Cleanstart lets you build your pages and posts with a Visual Builder and a great collection of Custom Shortcodes that offer flexibility and pixel-perfect design.</span>[/sc_featureteaser][/vc_column][/vc_row][vc_row title_style="fancy" background="dark_section" parallax="off" overlay="on" triangles="off" top_margin="off"][vc_column width="1/1"][sc_calltoaction subtitle="and make the web a little bit prettier" button="1" button_text="Buy this theme!" button_link="url:%23|title:Buy%20this%20theme!|" button_class="btn-primary" button_size="btn" title="Zm9jdXMlMjBvbiUyMHdoYXQlRTIlODAlOTlzJTIwJTNDc3Ryb25nJTNFJTNDc3BhbiUyMGNsYXNzJTNEJTIycm90YXRlJTIyJTNFaW1wb3J0YW50JTJDJTIwc2ltcGxlJTJDJTIwaW5ub3ZhdGl2ZSUzQyUyRnNwYW4lM0UlM0MlMkZzdHJvbmclM0U="]
      <h3 style="font-weight: 300; color: #efefef;">FOCUS ON WHAT\'S <span style="font-weight: bold;"><span class="rotate"><span class="rotating flip up"><span class="front">INNOVATIVE,</span><span class="back">IMPORTANT</span></span></span></span></h3>
      [/sc_calltoaction][/vc_column][/vc_row][vc_row title_header="RECENT PROJECTS FROM PORTFOLIO" title_subheader="we take pride in our work" title_style="fancy" background="light_section" parallax="off" overlay="on" triangles="on"][vc_column width="1/1"][sc_portfoliogrid layout="classic" layout_columns="3" results="3" orderby="date" category_filters="no"][sc_button button_link="url:http%3A%2F%2Fplethorathemes.com%2Fdev%2Fcleanstart%2F%3Fp%3D395|title:MORE%20WORK|target:%20_blank" button_class="btn-primary" button_size="btn"][/vc_column][/vc_row][vc_row title_header="OUR DEAR CLIENTS" title_subheader="all of them are satisfied" title_style="elegant" background="light_section" parallax="off" overlay="on" triangles="off"][vc_column width="1/1"][sc_clients client_images="112,111,110,113"][/vc_column][/vc_row]';

      vc_add_default_templates( $data );

      /** About Us Page Template */

      $data                 = array();
      $data['name']         = __( 'About Us Page', 'cleanstart' );
      $data['image_path']    = preg_replace( '/\s/', '%20', get_template_directory_uri() . '/assets/images/vc_template_about_us.jpg' ); 
      $data['custom_class'] = 'custom_template_for_vc_custom_template';
      $data['content']      = '[vc_row][vc_column width="1/1"][sc_Horizontalteaser title="We care for our work" text="Vivamus vestibulum neque quis nunc convallis venenatis. Nulla tristique lorem sit amet ipsum ornare sit amet feugiat nulla condimentum. Sed faucibus volutpat nunc, at ullamcorper augue elementum id. Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus. Vivamus vestibulum neque quis nunc convallis venenatis. Nulla tristique lorem sit amet ipsum ornare sit amet feugiat nulla condimentum." text_width="4" textposition="left" media_type="video" video_link="http://player.vimeo.com/video/71409522?title=0&amp;byline=0&amp;portrait=0" default_offset="0.5" orientation="horizontal"]Our team strives to achieve excellence in every aspect of the production process, from the preliminary hand-drawn sketches to the aftersales support. We carefully design our themes to be easy and flexible while making sure that most FAQ of our customers can be answered by our <a href="/documentation/">detailed documentation</a>. We focus on using the latest web standards and practices regarding UX guidelines and Wordpress theme development and strongly encourage our customers to follow us on this. The use of a child theme and the plugin-based development of &copy;Plethora Framework ensure hassle-free updates and peace of mind.[/sc_Horizontalteaser][/vc_column][/vc_row][vc_row title_style="elegant" background="dark_section" background_image="80" parallax="on" overlay="on" triangles="off"][vc_column width="1/1"][sc_calltoaction title="Z2l2ZSUyMHlvdXIlMjAlM0NzdHJvbmclM0VjcmVhdGl2ZSUzQyUyRnN0cm9uZyUzRSUyMGlkZWFzJTIwYSUyMGJvb3N0" subtitle="Mouse over our team photos to see a cool effect!" button="0" button_text="Buy this theme!" icon_image="85" button_link="Buy this theme!" button_class="btn-primary" button_size="btn"]GIVE YOUR <strong>CREATIVE</strong> IDEAS A BOOST[/sc_calltoaction][/vc_column][/vc_row][vc_row title_header="MEET OUR TEAM..." title_subheader="they are always up to something good!" title_style="fancy" background="light_section" parallax="off" overlay="off" triangles="on"][vc_column width="1/1"][sc_teamgrid columns="4" members="97,94,91,88" orderby="title" order="ASC" show_photo="1" photo_effect="1" show_profession="1" show_desc="1" show_social="1"][/vc_column][/vc_row]';

      vc_add_default_templates( $data );

      /** Services Page Template */

      $data                 = array();
      $data['name']         = __( 'Services Page', 'cleanstart' );
      $data['image_path']    = preg_replace( '/\s/', '%20', get_template_directory_uri() . '/assets/images/vc_template_services.jpg' ); 
      $data['custom_class'] = 'custom_template_for_vc_custom_template';
      $data['content']      = '[vc_row][vc_column width="1/1"][sc_Horizontalteaser title="Trust our vision!" text="Vivamus vestibulum neque quis nunc convallis venenatis. Nulla tristique lorem sit amet ipsum ornare sit amet feugiat nulla condimentum. Sed faucibus volutpat nunc, at ullamcorper augue elementum id. Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus. Vivamus vestibulum neque quis nunc convallis venenatis. Nulla tristique lorem sit amet ipsum ornare sit amet feugiat nulla condimentum. Sed faucibus volutpat nunc, at ullamcorper augu." text_width="4" textposition="left" media_type="2020" video_link="http://player.vimeo.com/video/71409522?title=0&amp;byline=0&amp;portrait=0" before_image="121" after_image="117" default_offset="0.5" orientation="horizontal"]Vivamus vestibulum neque quis nunc convallis venenatis. Nulla tristique lorem sit amet ipsum ornare sit amet feugiat nulla condimentum. Sed faucibus volutpat nunc, at ullamcorper augue elementum id. Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus. Vivamus vestibulum neque quis nunc convallis venenatis. Nulla tristique lorem sit amet ipsum ornare sit amet feugiat nulla condimentum. Sed faucibus volutpat nunc, at ullamcorper augu.[/sc_Horizontalteaser][/vc_column][/vc_row][vc_row title_header="WE PROVIDE SERVICES" title_subheader="that stand out for their quality" title_style="fancy" background="dark_section" parallax="off" overlay="on" triangles="on"][vc_column width="1/3"][sc_serviceteaser image="125" title="Design" text_content="Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus fermentum." button_enable="2" button_link="url:%23||" button_class="btn-primary" image_link="#" button_size="btn"]Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus fermentum.[/sc_serviceteaser][/vc_column][vc_column width="1/3"][sc_serviceteaser image="127" title="Development" text_content="Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus fermentum." button_enable="1" button_link="#" button_class="btn-primary" image_link="#" button_size="btn"]Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus fermentum.[/sc_serviceteaser][sc_button button_link="url:%23|title:CALL%20TO%20ACTION|" button_class="btn-primary" button_size="btn"][/vc_column][vc_column width="1/3"][sc_serviceteaser image="126" title="Support" text_content="Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus fermentum." button_enable="1" button_link="#" button_class="btn-primary" image_link="#" button_size="btn"]Quisque at lectus leo, nec placerat mi. Curabitur egestas eleifend interdum. Suspendisse potenti. Suspendisse nec risus fermentum.[/sc_serviceteaser][/vc_column][/vc_row][vc_row title_header="PRICE PLANS FOR SERVICES" title_subheader="there is always one that fits you" title_style="fancy" background="light_section" parallax="off" overlay="on" triangles="on" top_margin="off"][vc_column width="1/3"][sc_priceplan header_title="<strong>Lite Plan</strong>" header_subtitle="This is where you start" pricing="$150<small>/year</small>" special="0" features="3" feature_1="1 <strong>Design Template</strong>" feature_2="2 <strong>Revisions</strong>" feature_3="5 <strong>HTML Pages</strong>" feature_4="Feature <strong>Four</strong>" feature_5="Feature <strong>Five</strong>" feature_6="Feature <strong>Six</strong>" feature_7="Feature <strong>Seven</strong>" feature_8="Feature <strong>Eight</strong>" feature_9="Feature <strong>Nine</strong>" feature_10="Feature <strong>Ten</strong>" button_text="Get it now!" button_link="url:www.leonart.gr||"][/vc_column][vc_column width="1/3"][sc_priceplan header_title="<strong>Medium Plan</strong>" header_subtitle="this is what you should choose" pricing="$250<small>/year</small>" special="1" features="3" feature_1=" <strong>1</strong>Design Template" feature_2=" <strong>2</strong>Revisions" feature_3="<strong>5</strong>HTML Pages" feature_4="Feature <strong>Four</strong>" feature_5="Feature <strong>Five</strong>" feature_6="Feature <strong>Six</strong>" feature_7="Feature <strong>Seven</strong>" feature_8="Feature <strong>Eight</strong>" feature_9="Feature <strong>Nine</strong>" feature_10="Feature <strong>Ten</strong>" button_text="Get it now!" button_link="url:%23||"][/vc_column][vc_column width="1/3"][sc_priceplan header_title="<strong>Pro Plan</strong>" header_subtitle="this is what you really need" pricing="$350<small>/year</small>" special="0" features="3" feature_1="<strong>1</strong>Design Template" feature_2="<strong>2</strong> Revisions" feature_3="<strong>5</strong>HTML Pages" feature_4="Feature <strong>Four</strong>" feature_5="Feature <strong>Five</strong>" feature_6="Feature <strong>Six</strong>" feature_7="Feature <strong>Seven</strong>" feature_8="Feature <strong>Eight</strong>" feature_9="Feature <strong>Nine</strong>" feature_10="Feature <strong>Ten</strong>" button_text="Get it now!" button_link="url:%23||"][/vc_column][/vc_row][vc_row title_style="elegant" background="dark_section" background_image="434" parallax="on" overlay="on" triangles="off" top_margin="off"][vc_column width="1/1"][sc_calltoaction icon_image="135" title="d2UlMjBkZXNpZ24lMjAlM0NzdHJvbmclM0V2YWx1ZSUzQyUyRnN0cm9uZyUzRSUyMGludG8lMjBwcm9maXQ=" subtitle="our <strong>customers</strong> are always <strong>happy</strong>!" button="0" button_text="Buy this theme!" button_link="Buy this theme!" button_class="btn-primary" button_size="btn"]WE DESIGN <strong>VALUE</strong> INTO PROFIT[/sc_calltoaction][/vc_column][/vc_row]';
      vc_add_default_templates( $data );

      /** Contact Page Template */

      $data                 = array();
      $data['name']         = __( 'Contact Page', 'cleanstart' );
      $data['image_path']   = preg_replace( '/\s/', '%20', get_template_directory_uri() . '/assets/images/vc_template_contact.jpg' ); 
      $data['custom_class'] = 'custom_template_for_vc_custom_template';
      $data['content']      = '[vc_row][vc_column width="2/6"][sc_contactcard brand_logo="451" brand_name="PLETHORA THEMES" industry="Web-Development Company"]<address>795 Folsom Ave, Suite 600 San Francisco, CA 94107</address><abbr title="Phone">P:</abbr> (123) 456-7890<abbr title="Email">E:</abbr> <a href="mailto:#">first.last@example.com</a>[/sc_contactcard][/vc_column][vc_column width="4/6"][vc_column_text][contact-form-7 id="4" title="Contact form 1"][/vc_column_text][/vc_column][/vc_row][vc_row title_style="fancy" background="dark_section" background_image="1464" parallax="on" top_margin="off" triangles="off"][vc_column width="1/1"][sc_newsletterform title="NEVER MISS A <strong>SINGLE</strong> FEATURE" subtitle="subscribe to our awesome newsletter" email_placeholder="Give Us your e-mail..." button_text="Go AHEAD!"][/vc_column][/vc_row]';

      vc_add_default_templates( $data );

    }  
     /**
     * Returns header section blog featured image
     *
     * @param 
     * @return string
     *
     */
    // static function html_headermedia_blog() {

    //   $html = '';
    //   $blog_header_img = self::option( 'blog-header-img');

    //   if ( !empty( $blog_header_img )) { 

    //     $html = ' style="background-image: url('. $blog_header_img['url'] .');"';

    //   }
    //   return $html;

    // }

     /**
     * Returns header section 404 image
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_404() {

      $html = '';
      $four04_header_img = self::option( '404-header-img');

      if ( !empty( $four04_header_img )) { 

        $html = ' style="background-image: url('. $four04_header_img['url'] .');"';

      }
      return $html;

    }

    /**
     * Returns featured media slider
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_slider() {

      $html     = '';
      $sliderid = self::option( PLETHORA_META_PREFIX . 'header-media-slider', 0);
      $slides   = self::option( PLETHORA_META_PREFIX . 'slider-slides', array(), $sliderid);

      // $height   = self::option( PLETHORA_META_PREFIX . 'header-media-dimensions', array());
      // $units    = $height['units'];
      // $height   = intval($height['height']);
      // $height --> Array ( [height] => 240px [units] => px )

      if ( !empty( $slides ) && is_array( $slides )) { 

        $html .= '<section id="slider_wrapper" class="slider_wrapper full_page_photo">'."\n";
        $html .= '    <div id="main_flexslider" class="flexslider">'."\n";
        $html .= '         <ul class="slides">'."\n";

        foreach ( $slides as $slide ) { 
            $title  =  ( !empty( $slide['title'] )) ? $slide['title'] : '';
            $descr  =  ( !empty( $slide['description'] )) ? $slide['description'] : '';
            $url    =  ( !empty( $slide['url'] )) ? $slide['url'] : '';
            $image  =  ( !empty( $slide['image'] )) ? $slide['image'] : '';
            $html .= '              <li class="item" style="background-image: url('.  $image .')">'."\n";
            $html .= '                   <div class="container">'."\n";
            $html .= '                        <div class="carousel-caption animated bounceInUp">'."\n";
            if ( !empty( $title )) { $html .= '                             <h1>'. $title .'</h1>'."\n"; }
            if ( !empty( $descr )) { $html .= '                             <p class="lead skincolored">'. $descr .'</p>'."\n"; }
            $html .= '                        </div>'."\n";
            $html .= '                   </div>'."\n";
            $html .= '              </li>'."\n";
        }

        $html .= '         </ul>'."\n";
        $html .= '    </div>'."\n";
        $html .= '</section>'."\n";

        // Enqueue flexslider script in the footer
        wp_enqueue_script(  'flexslider-cleanstart' );
                 
        // Additional config ---> send slider settings to init
        $slider_options = Plethora_Theme::get_slider_options( $sliderid );

        $slider = array('slider_options'=> $slider_options) ;
        
        wp_register_script( 'fmslider',  THEME_ASSETS_URI . '/cleanstart_fmslider.js',  array('flexslider-cleanstart'),  '', TRUE ); // OK
        wp_localize_script( 'fmslider', 'plethora_slider', $slider );
        wp_enqueue_script ( 'fmslider' );

      }
      
      return $html;
    } 


     /**
     * Returns header section featured image
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_featuredimage() {

      $html = '';
        $postid = self::get_the_id();
        if ( has_post_thumbnail( $postid ) ) { 

          $header_image_src = wp_get_attachment_image_src(get_post_thumbnail_id( $postid ), 'large');
          $html = ' style="background-image: url('. esc_url( $header_image_src[0] ) .');"';

        } 

      return $html;
    }

     /**
     * Returns header section other image
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_otherimage() {

      $html = '';
      $otherimage = self::option( PLETHORA_META_PREFIX . 'header-media-otherimage');

      if ( isset( $otherimage['url'] ) &&  !empty( $otherimage['url'] )) { 

        $html = ' style="background-image: url('. esc_url( $otherimage['url'] ) .');"';

      }

      return $html;

    }

     /**
     * Returns featured video (local video )
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_localvideo() {

      $html = '';

      // Get local video options
      $localvideo     = self::option( PLETHORA_META_PREFIX .'header-media-localvideo');
      $video_poster   = self::option( PLETHORA_META_PREFIX .'header-media-localvideo-poster'); // Get video poster
      $video_controls = self::option( PLETHORA_META_PREFIX .'header-media-localvideo-controls', 'true'); // Get Controls option
      $video_autoplay = self::option( PLETHORA_META_PREFIX .'header-media-localvideo-autoplay', 'false'); // Get Autoplay option
      $video_loop     = self::option( PLETHORA_META_PREFIX .'header-media-localvideo-loop', 'false'); // Get Loop option
      $video_sound    = self::option( PLETHORA_META_PREFIX .'header-media-localvideo-sound', 'false'); //Get Sound option

      if ( isset( $localvideo['url'] ) && !empty($localvideo['url'])) { 

          // Get video filetype
          $video_ext = ( isset( $localvideo['url'] ) && !empty($localvideo['url'])) ? pathinfo($localvideo['url'], PATHINFO_EXTENSION ) : '';

          // Allow only mp4/flv/webm video formats
          if ( $video_ext == 'mp4' || $video_ext == 'flv' || $video_ext == 'webm' ) { 
              
              $video_poster_img = ( isset( $video_poster['url'] ) && !empty($video_poster['url'] )) ? $video_poster['url'] : '';
              // Return this as a part of attributes for a div tag
              $html  .= ' id="video" data-video="'. esc_url( $localvideo['url'] ) .'" data-imagefallback="'. esc_url( $video_poster_img ) .'"';

              // Register & Enqueue flexslider script in the footer
              wp_register_script( 'jquery-ui-custom',   THEME_ASSETS_URI . '/js/jquery-ui-1.8.22.custom.min.js',       array( 'jquery' ),  '', TRUE ); // ok
              wp_register_script( 'imagesloaded',       THEME_ASSETS_URI . '/js/jquery.imagesloaded.min.js',          array('jquery'), '', TRUE); // ok
              wp_register_script( 'plethora-videojs',   THEME_ASSETS_URI . '/js/video.js',          array('jquery-ui-custom'), '', TRUE); // ok
              wp_register_script( 'plethora-bigvideo',  THEME_ASSETS_URI . '/js/bigvideo.js',       array('plethora-videojs','imagesloaded'), '', TRUE); // ok
              wp_enqueue_script(  'plethora-videojs' );
              wp_enqueue_script(  'plethora-bigvideo' );
              wp_register_script( 'bigvideo-init',  THEME_ASSETS_URI . '/cleanstart_fmvideo.js',  array('plethora-bigvideo'), '', TRUE); // ok
              wp_enqueue_script(  'bigvideo-init' );

              // Additional config ---> send video settings to init
              $video_options = array();
              $video_options['video_controls']    = ( $video_controls === 'true' ) ? true : false;
              $video_options['video_autoplay']    = ( $video_autoplay === 'true' ) ? true : false;
              $video_options['video_loop']        = ( $video_loop === 'true' ) ? true : false;
              $video_options['video_sound']       = ( $video_sound === 'true' ) ? true : false;

              $video_options = json_encode( $video_options );
              $video = array('video_options'=> $video_options) ;
              wp_localize_script( 'bigvideo-init', 'plethora_video', $video );
          }
      }  
      
      return $html;
    }

     /**
     * Returns featured Google Map
     *
     * @param 
     * @return string
     *
     */
    static function html_headermedia_googlemap() {

      $html = '';
      $map_lat      = self::option( PLETHORA_META_PREFIX .'header-media-map-lang');
      $map_lng      = self::option( PLETHORA_META_PREFIX .'header-media-map-long');
      $map_type     = self::option( PLETHORA_META_PREFIX .'header-media-map-type', 'ROADMAP'); 
      $map_zoom     = self::option( PLETHORA_META_PREFIX .'header-media-map-zoom', '12'); 
      $map_mark     = self::option( PLETHORA_META_PREFIX .'header-media-map-mark', 'true'); 
      $map_controls = self::option( PLETHORA_META_PREFIX .'header-media-map-controls', 'true'); 
      $map_snazzy   = self::option( PLETHORA_META_PREFIX .'header-google-maps-snazzy', '');

      if ( !empty($map_lat) && !empty($map_lng) ) { 

        wp_enqueue_script(  'plethora-gmap', 'http://maps.google.com/maps/api/js?sensor=false', array(), NULL, true);
        wp_register_script( 'gmap-init',  THEME_ASSETS_URI . '/cleanstart_fmgmap.js', array('plethora-gmap'), '', TRUE); // ok
        wp_enqueue_script(  'gmap-init' );

        // Additional config ---> send map settings to init
        $map_options                 = array();
        $map_options['map_lat']      = $map_lat;
        $map_options['map_lng']      = $map_lng;
        $map_options['map_type']     = $map_type;
        $map_options['map_zoom']     = $map_zoom;
        $map_options['map_mark']     = $map_mark;
        $map_options['map_controls'] = $map_controls;

        if ( $map_snazzy !== '' ){
          $map_snazzy = json_decode($map_snazzy);
          if ( $map_snazzy !== NULL ){
            $map_options['map_snazzy'] = $map_snazzy;
          }
        }
         
        $map_options = json_encode( $map_options );
        $map         = array('map_options'=> $map_options) ;

        wp_localize_script( 'gmap-init', 'plethora_map', $map );

        $html .= 'ok';
      }

       return $html;
   
    }
      /**
     * Returns featured image. Use only inside a loop
     * Attention...use get_the_ID() method to retrieve the postid ( not self::get_the_id() )
     * Also, the self:option() calls if this is_single() must be called with all their attributes ( option($option_id, $user_value, $postid) )
     * @param 
     * @return string
     *
     */
    static function html_content_featuredimage() {

      $html = '';
      
      if ( has_post_thumbnail() ) { 

        $featured_image_src = wp_get_attachment_image_src(get_post_thumbnail_id(), 'large');

        if ( !empty( $featured_image_src )) {
          if ( !is_single()) { 

             $html .= '<a href="'. get_permalink( get_the_ID() ) .'" title="'. esc_attr( get_the_title()) .'"><img alt="'. esc_attr( get_the_title() ) .'" src="'. esc_url( $featured_image_src[0] ) .'"></a>';

          } else { 

             $html .= '<img alt="'. esc_attr( get_the_title() ).'" src="'. esc_url( $featured_image_src[0] ) .'">';

          }
        }
      }
      return $html;
    } 
    

    /**
     * Returns featured video (embeded video ). Use only inside a loop
     * Attention...use get_the_ID() method to retrieve the postid ( not self::get_the_id() )
     * Also, the self:option() calls if this is_single() must be called with all their attributes ( option($option_id, $user_value, $postid) )
     *
     * @param $video_position, $is_blog, $postid 
     * @return string
     *
     */
    static function html_content_video() {

      $html = '';
      $postid = get_post() ? get_the_ID() : NULL; // Get the postid using the get_the_ID()
      $post_type = get_post_type();

      // Check if this post is forced to display a featured image on list view ( for classic posts only )
      if ( $post_type == 'post' && !is_single() ) {

        $listview     = self::option( PLETHORA_META_PREFIX .'post-listview', 'inherit', $postid );
        if ( $listview == 'featuredimage' ) { 

          $html = self::html_content_featuredimage();
          return $html;

        }
      }
      // Show the vid
      $embedvideo     = self::option( PLETHORA_META_PREFIX .'content-video', '', $postid );
      
      if ( !empty( $embedvideo )) {   

             // $html .= wp_oembed_get( $embedvideo, array('width' => 740));
             $html .= wp_oembed_get( $embedvideo );
      }  
      
      return $html;
    } 

    
    /**
     * Returns featured audio html (embeded audio ). Use only inside a loop
     * Attention...use get_the_ID() method to retrieve the postid ( not self::get_the_id() )
     * Also, the self:option() calls if this is_single() must be called with all their attributes ( option($option_id, $user_value, $postid) )
     * 
     * @param $position_ignore
     * @return null
     *
     */
    static function html_content_audio() {

      $html = '';
      $postid = get_post() ? get_the_ID() : NULL; // Get the postid using the get_the_ID()
      $post_type = get_post_type();

      // Check if this post is forced to display a featured image on list view ( for classic posts only )
      if ( $post_type == 'post' && !is_single() ) {

        $listview     = self::option( PLETHORA_META_PREFIX .'post-listview', 'inherit', $postid );
        if ( $listview == 'featuredimage' ) { 

          $html = self::html_content_featuredimage();
          return $html;

        }
      }
      // Show the audio

      $embedaudio     = self::option( PLETHORA_META_PREFIX .'content-audio', '',  $postid );
      
      if ( !empty( $embedaudio )) {   

             $html .= wp_oembed_get( $embedaudio, array('width' => 740));
      }  
      
      return $html;

    }   

    /**
     * Returns post gallery. Use only inside a loop
     * Attention...use get_the_ID() method to retrieve the postid ( not self::get_the_id() )
     * Also, the self:option() calls if this is_single() must be called with all their attributes ( option($option_id, $user_value, $postid) )
     * @param 
     * @return string
     *
     */
    static function html_post_gallery() {

      $html  = '';
      $post_type = get_post_type();
      $postid = get_post() ? get_the_ID() : NULL; // Get the postid using the get_the_ID()
      // Check if this post is forced to display a featured image on list view ( for classic posts only )
      if ( $post_type == 'post' && !is_single() ) {

        $listview     = self::option( PLETHORA_META_PREFIX .'post-listview' );
        if ( $listview == 'featuredimage' ) { 

          $html = self::html_content_featuredimage();
          return $html;

        }
      }

      $gallery_photos = self::option( PLETHORA_META_PREFIX. 'post-slides', array());
      if (is_array( $gallery_photos )) {
        
        $html .= '                    <div class="flexslider" id="gallery_'.$postid.'">'."\n";
        $html .= '                         <ul class="slides">'."\n";
        foreach ( $gallery_photos as $gallery_photo ) { 
            $html .= '                              <li class="item" data-thumb="'. $gallery_photo['image'].'" style="background-image: url('. $gallery_photo['image'].')">
      '."\n";
            $html .= '                                   <div class="container"> <a href="'. esc_url( $gallery_photo['image'] ).'" class="lightbox_portfolio" title="'. esc_attr( $gallery_photo['title'] ).'"></a>'."\n";
            $html .= '                                        <div class="carousel-caption">'."\n";

            if (!empty($gallery_photo['title'])) { 
              $html .= '                                             <p class="lead">'. $gallery_photo['title'] .'</p>'."\n";
            }

            $html .= '                                        </div>'."\n";
            $html .= '                                   </div>'."\n";
            $html .= '                              </li>'."\n";
        } 
        $html .= '                         </ul>'."\n";
        $html .= '                    </div>'."\n";
        $html .= '<script>'."\n";
        $html .= 'jQuery(document).ready(function() {'."\n";
        $html .= '"use strict";'."\n";
        $html .= '    jQuery(\'#gallery_'.$postid.'\').flexslider({'."\n";
        $html .= '        animation: "slide",'."\n";
        $html .= '        controlNav: true,'."\n";
        $html .= '        animationLoop: true,'."\n";
        $html .= '        slideshow: true,'."\n";
        $html .= '        touch: true,'."\n";
        // $html .= '        itemWidth: 210,'."\n";
        // $html .= '        itemMargin: 10,'."\n";
        $html .= '      });'."\n";
        $html .= '});'."\n";
        $html .= '</script>'."\n";


  
      }
      return $html;

    }    


    /**
     * Returns post date html. Use only inside a loop
     * Attention...use get_the_ID() method to retrieve the postid ( not self::get_the_id() )
     * Also, the self:option() calls if this is_single() must be called with all their attributes ( option($option_id, $user_value, $postid) )
     *
     * @param 
     * @return string
     *
     */
    static function html_post_info() {
      $html = '';
      $postid = get_post() ? get_the_ID() : NULL; // Get the postid using the get_the_ID()

      // get options depending on the view
      if ( is_single() ) { 

        $show_categories  = self::option( PLETHORA_META_PREFIX .'post-info-category', 1, $postid );
        $show_tags        = self::option( PLETHORA_META_PREFIX .'post-info-tags', 1, $postid );
        $show_author      = self::option( PLETHORA_META_PREFIX .'post-info-author', 1, $postid );
        $show_date        = self::option( PLETHORA_META_PREFIX .'post-info-date', 1, $postid );
        $show_comments    = self::option( PLETHORA_META_PREFIX .'post-info-comments', 1, $postid );

      } else { 

        $show_categories  = self::option( 'blog-info-category', 1 );
        $show_tags        = self::option( 'blog-info-tags', 1 );
        $show_author      = self::option( 'blog-info-author', 1 );
        $show_date        = self::option( 'blog-info-date', 1 );
        $show_comments    = self::option( 'blog-info-comments', 1 );

      }

      // date info
      $html_date  = '';
      if ( $show_date ) { 

        $html_date  = '<span class="post_info post_date"><i class="fa fa-clock-o"></i> '.get_the_date('M d, Y') .'</span> ';

      }

      // author info
      $html_author  = '';
      if ( $show_author ) { 

        $html_author  = '<span class="post_info post_author"><i class="fa fa-user"></i> <a href="'. get_author_posts_url(get_the_author_meta( 'ID' )).'" title="' . esc_attr( sprintf( get_the_author() )) . '">'. get_the_author() .'</a></span> ';
      }


      // categories info
      $html_categories  = '';
      if ( $show_categories ) { 
        $categories = get_the_category();
        $sep = '';
        $count = 0;
        
        if ( $categories ) {
          $html_categories .= '<i class="fa fa-folder"></i> ';
          foreach($categories as $key=>$category) {

            $count = $count + 1;
            $sep = $count > 1 ? ', ': '';
            $html_categories .= $sep .'<a href="'.get_category_link( $category->term_id ).'" title="' . esc_attr( sprintf( __( "View all posts in category: %s", 'cleanstart' ), $category->name ) ) . '">'.$category->cat_name.'</a>';
        
          }
          $html_categories = '<span class="post_info post_categories">'. $html_categories .'</span> ';
        }
      }

      // tags info
      $html_tags  = '';
      if ( $show_tags ) { 
        $tags = get_the_tags();
        $sep = '';
        $count = 0;
        
        if ( $tags ) {
          $html_tags .= '<i class="fa fa-tag"></i> ';

          foreach($tags as $key=>$tag) {
            $count = $count + 1;
            $sep = $count > 1 ? ', ': '';
            $html_tags .= $sep .'<a href="'.get_tag_link( $tag->term_id ).'" title="' . esc_attr( sprintf( __( "View all posts tagged with: %s", 'cleanstart' ), $tag->name ) ) . '">'. $tag->name .'</a>';
        
          }
          $html_tags = '<span class="post_info post_tags">'. $html_tags .'</span> ';
        }
      }

      // comments info
      $html_comments  = '';
      if ( $show_comments && comments_open()  ) { 

          $num_comments = get_comments_number();
          
          if ( $num_comments > 0 ) {

            $html_comments = '<i class="fa fa-comments"></i> <a href="'. esc_url( get_permalink() .'#post_comments').'"> '. $num_comments .'</a>' ;

          } 
           $html_categories = '<span class="post_info post_comments">'. $html_categories .'</span> ';
     }

      $html = $html_date . $html_author . $html_categories . $html_tags . $html_comments;

      $display_title = Plethora_Theme::option( PLETHORA_META_PREFIX .'post-title-oncontent', 'display', $postid);          // Where to put the title / subtitles
      // wrap them depending on the view
      if ( is_single() && $display_title == 'display' ) {      // Displayed on single view, with header

        $html = '<small>'. $html .'</small>';

      } elseif ( is_single() && $display_title == 'hide' ) {   // Displayed on single view, with hidden header

        $html = '<div class="post_sub">'. $html .'</div>';

      } else {                                                // Catalog view

        $html = '<div class="post_sub">'. $html .'</div>'; 

      }

      return $html;
    
    }

    /**
     * Returns side corners for all the positions
     *
     * @param $position ( header, content, footer )
     * @return string
     *
     */
    static function html_triangles( $position ) {

    if ( empty($position) ) { return; }
      
      $html = '';
      $triangles = self::option( PLETHORA_META_PREFIX . $position .'-triangles', 'display');

      if ( $triangles == 'display') { 
            $html .= '<div class="container triangles-of-section">'."\n";
            $html .= '  <div class="triangle-up-left"></div>'."\n";
            $html .= '  <div class="square-left"></div>'."\n";
            $html .= '  <div class="triangle-up-right"></div>'."\n";
            $html .= '  <div class="square-right"></div>'."\n";
            $html .= '</div>'."\n";

      }
      return $html;
    }


    /**
     * Returns featured media template_part
     *
     * @param 
     * @return null
     *
     */
    static function html_twitterfeed() {

      $twitterfeed = self::option( PLETHORA_META_PREFIX . 'footer-twitterfeed', 0);

      if ( $twitterfeed == 1 ) { 

        get_template_part('includes/partials/element', 'twitterfeed');

      }    
    }    


    /**
     * Returns footer info bar ()
     *
     * @param 
     * @return string
     *
     */
    static function html_footerinfobar() {

      $footer_infobar           = self::option( 'footer-infobar', 0);
      $footer_infobar_copyright = self::option( 'footer-infobar-copyright', 0);
      $footer_infobar_credits   = self::option( 'footer-infobar-credits', 0);

      $html = '';

      if ( $footer_infobar == '1' ) {

        $html .= '         <div class="copyright">';
        $html .= '              <div class="container">';

        $html .= '                   <div class="row">';
        $html .= '                        <div class="col-sm-4 col-md-4 infobar_copyright">';
        $html .= $footer_infobar_copyright;
        $html .= '                        </div>';
        $html .= '                        <div class="col-sm-4 col-md-4"></div>';
        $html .= '                        <div class="text-right col-sm-4 col-md-4 infobar_credits">';
        $html .= $footer_infobar_credits;
        $html .= '                        </div>';
        $html .= '                   </div>';
        $html .= '              </div>';
        $html .= '         </div>';
        $html .= '';

      } 

      return $html;
    }


    /**
     * Returns pagination for blog
     *
     * @param 
     * @return string
     *
     */

    static function blog_pagination($pages = '', $range = 5){

         $html = '';

         $showitems = ($range * 2)+1;  
         global $paged;
         if(empty($paged)) $paged = 1;

         if($pages == '')
         {
             global $wp_query;
             $pages = $wp_query->max_num_pages;
             if(!$pages)
             {
                 $pages = 1;
             }
         }   

        if ( $pages != 1 ) {

            $html .= '<div class="pagination_wrapper">';
            $html .= '  <ul class="pagination pagination-centered">';
            $html .= '    <li>'. get_previous_posts_link( __('Prev', 'cleanstart') ).'</li>';
            if ( $paged > 2 && $paged > $range+1 && $showitems < $pages ) { 

              $html .= '    <li><a href="'.get_pagenum_link(1).'">&laquo;</a></li>'; 

            }
            if ( $paged > 1 && $showitems < $pages ) { 

              $html .= '    <li><a href="'.get_pagenum_link($paged - 1).'">&lsaquo;</a></li>'; 

            }
            for ( $i=1; $i <= $pages; $i++ ) { 

              if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems )) {

              $class = ( $paged == $i ) ? $class = ' class="active"': $class = '';
              $html .= '    <li'.$class.'><a href="'.get_pagenum_link($i).'">'.$i.'</a></li>';
              
              }
            }
            if ($paged < $pages && $showitems < $pages) {

              $html .= '    <li><a href="' .get_pagenum_link($paged + 1). '">&rsaquo;</a></li>';  

            }
            if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) {

              $html .= '    <li><a href="' .get_pagenum_link($pages).'">&raquo;</a></li>';

            }
            
            $html .= '    <li>'. get_next_posts_link( __('Next', 'cleanstart') ).'</li>';
            $html .= '  </ul>';
            $html .= '</div>';
        
        }

        return $html;
    }


    static function excerpt($text) {

      $chars_limit = 140;
      $chars_text = strlen($text);
      $text = $text." ";
      $text = substr($text,0,$chars_limit);
      $text = substr($text,0,strrpos($text,' '));
      if ($chars_text > $chars_limit){$text = $text."...";}
      return $text;
    
    }

    /**
     * Returns portfolio gallery (single post view)
     *
     * @param 
     * @return string
     *
     */
    static function html_portfolio_gallery() {

      $gallery_photos = self::option( PLETHORA_META_PREFIX. 'portfolio-slides', array());
      $html  = '';
      $counter = 0;

      // Since the slides field default behaviour creates an array, we implement another method for checking if users created a slideshow
      foreach ( $gallery_photos as $gallery_photo ) { 

        $counter = !empty( $gallery_photo['image'] ) ? $counter + 1 : $counter;

      }

      if ( $counter > 0) { 
          $html .= '                    <div class="flexslider" id="portfolio_slider">'."\n";
          $html .= '                         <ul class="slides">'."\n";
          foreach ( $gallery_photos as $gallery_photo ) { 
              $html .= '                              <li class="item" data-thumb="'. $gallery_photo['image'].'" style="background-image: url('. $gallery_photo['image'].')">
        '."\n";
              $html .= '                                   <div class="container"> <a href="'. esc_url( $gallery_photo['image'] ).'" class="lightbox_single" title="'. esc_attr( $gallery_photo['title'] ).'" data-imagelightbox="gallery"></a>'."\n";
              $html .= '                                        <div class="carousel-caption">'."\n";
              if (!empty($gallery_photo['title'])) { 
              $html .= '                                             <p class="lead">'. $gallery_photo['title'] .'</p>'."\n";
              }
              $html .= '                                        </div>'."\n";
              $html .= '                                   </div>'."\n";
              $html .= '                              </li>'."\n";
            } 
          $html .= '                         </ul>'."\n";
          $html .= '                    </div>'."\n";

          $html .= '                    <div id="carousel" class="flexslider">'."\n";
          $html .= '                         <ul class="slides">'."\n";
      
          foreach ( $gallery_photos as $gallery_photo ) {
            // have to find media library id, in order to retrieve the medium size version. If image is an external url, then use the option's 'thumb' value
            $image_id = Plethora_Helper::get_imageid_by_url( $gallery_photo['image'] );
            if ( !empty( $image_id )) { 

              $attachment = wp_get_attachment_image_src( $image_id, 'thumb-portfolio' );
              $gallery_thumb = isset( $attachment[0] ) ? $attachment[0] : '';

            } else { 

              $gallery_thumb = $gallery_photo['thumb'];

            }
            
            $html .= '                              <li> <img src="'. esc_url( $gallery_thumb ).'" alt="'. esc_attr( $gallery_photo['title'] ).'"> </li>'."\n";
          } 

          $html .= '                         </ul>'."\n";
          $html .= '                    </div>'."\n";
      }
      return $html;

    }

    /**
     * Returns portfolio details (single post view)
     *
     * @param 
     * @return string
     *
     */
    static function html_portfolio_details() {

      $details_status = self::option( PLETHORA_META_PREFIX .'portfolio-infofields-box');
 
      if ( $details_status != 'display' ) { return; }

      $postid = self::get_the_id();
      $html     = '';
      $layout   = self::option( PLETHORA_META_PREFIX. 'portfolio-layout' );
      $but_title= self::option( PLETHORA_META_PREFIX. 'portfolio-site-title' );
      $but_url  = self::option( PLETHORA_META_PREFIX. 'portfolio-site-url' );
      $fields     = self::option( PLETHORA_META_PREFIX .'portfolio-infofields' );
      $rating   = self::option( PLETHORA_META_PREFIX. 'portfolio-rating' );

      $args = array('hierarchical' => 0,'taxonomy' => 'project-type' ); 
      $project_types = wp_get_post_terms( $postid , 'project-type', array( 'fields' => 'names' ));
      $project_types = implode(', ', $project_types);

      //version full
      if ( $layout == 'full') { 
        $html .= '                              <div class="well col-sm-3 col-md-3">'."\n";
        if( !empty($project_types)) { $html .= '                                   <p><strong>'.__('Category', 'cleanstart').': </strong>'. $project_types .'</p>'."\n"; }
        if( !empty($fields) ) {      $html .=  $fields ."\n"; }
        if( !empty($rating) ) {       $html .= '                                   <p><strong>'.__('Rating', 'cleanstart').': </strong><span class="rating r'.$rating.'"></span></p>'."\n"; }
        if( !empty($but_title) && !empty($but_url) ) { $html .= '                  <p><a href="'. esc_url( $but_url ).'" class="btn btn-danger center-block" target="_blank">'. $but_title .'</a></p>'."\n"; }
       $html .= '                              </div>'."\n";
        $html .= '                              <br>'."\n";

      } elseif ( $layout == 'side') { 
        //version side
        $html .= '                                   <div>'."\n";
        if( !empty($project_types)) { $html .= '                                        <p><strong>'.__('Category', 'cleanstart').': </strong>'. $project_types .'</p>'."\n"; }
        if( !empty($fields) ) {      $html .=  $fields ."\n"; }
        if( !empty($rating) ) {       $html .= '                                        <p><strong>'.__('Rating', 'cleanstart').': </strong><span class="rating r'.$rating.'"></span></p>'."\n"; }
        $html .= '                                   </div>'."\n";
        $html .= '                                   <br>'."\n";
        $html .= '                                   <br>'."\n";
        if( !empty($but_title) && !empty($but_url) ) { $html .= '                                   <a href="'. esc_url( $but_url ) .'" class="btn btn-danger center-block" target="_blank">'. $but_title .'</a>'."\n";}
      }

      return $html;

    }

    /**
     * Returns portfolio related posts (single post view)
     *
     * @param 
     * @return string
     *
     */

    static function html_portfolio_related() {

      $postid = self::get_the_id();
      $html = '';

      //check post/theme settings for display. If is hidden...then get out of here!
      $related = self::option(  PLETHORA_META_PREFIX .'portfolio-related', 'hide' );
      if ($related == 'hide') { return; }    

      // Get Related Portfolio override/default options
      $related_header   = self::option(  PLETHORA_META_PREFIX .'portfolio-related-header', __('Related Projects', 'cleanstart') );
      $related_results  = self::option(  PLETHORA_META_PREFIX .'portfolio-related-results', '3' );
      
      // Get portfolio's project type(s). 
      $tags = wp_get_post_terms( $postid , 'project-type', array( 'fields' => 'ids' ));

      if ( !empty($tags) ) {
        $related_type = $tags[0]; // take the first set project type
        $args = array(
          'posts_per_page'=>$related_results,
          'ignore_sticky_posts'=>1,
          'post_type' => 'portfolio',
          'post__not_in' => array($postid),
          'tax_query' => array(
                      array(
                        'taxonomy' => 'project-type',
                        'field' => 'id',
                        'terms' => array($related_type),
                      )
          )        
        );
        $rel_query = new WP_Query($args);
        if( $rel_query->have_posts() ) {

          $html .= '          <section class="portfolio_teasers_wrapper">'."\n";
          $html .= '               <div class="container">'."\n";
          $html .= '                    <h2 class="elegant centered section_header">'. $related_header .'<small></small></h2>'."\n";
          $html .= '                    <div class="portfolio_strict row">'."\n";

          while ($rel_query->have_posts()) { 

            $rel_query->the_post();
            
            $project_types = wp_get_post_terms( $postid , 'project-type', array( 'fields' => 'names' ));
            $project_types = implode(', ', $project_types);
            $thumb_url = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ),  'large') ;

            $html .= '                         <div class="col-sm-4 col-md-4">'."\n";
            $html .= '                              <div class="portfolio_item">'."\n";
            $html .= '                                <a href="'. get_permalink() .'">'."\n";
            $html .= '                                   <figure style="background-image:url('. esc_url( $thumb_url[0] ) .')">'."\n";
            $html .= '                                        <figcaption>'."\n";
            $html .= '                                             <div class="portfolio_description">'."\n";
            $html .= '                                                  <h3>'. get_the_title() .'</h3>'."\n";
            $html .= '                                                  <span class="cross"></span>'."\n";
            $html .= '                                                  <p>'. $project_types .'</p>'."\n";
            $html .= '                                             </div>'."\n";
            $html .= '                                        </figcaption>'."\n";
            $html .= '                                   </figure>'."\n";
            $html .= '                                </a>'."\n";
            $html .= '                              </div>'."\n";
            $html .= '                         </div>'."\n";         

          } 
          
          $html .= '                    </div>'."\n";
          $html .= '               </div>'."\n";
          $html .= '          </section>'."\n";

        }

        wp_reset_query();
      }
      return $html;
    }


  } 

$cleanstart_theme = Plethora_Theme::init();