<?php
/*
Plugin Name: Plethora Themes Framework
Plugin URI: http://plethorathemes.com/
Description: Contains all the core functionality of Plethora WP themes
Author: Plethora Themes
Author URI: http://plethorathemes.com/
Text Domain: plethora-framework
Version: 1.1
*/


if ( ! defined( 'ABSPATH' ) ) exit; // NO DIRECT ACCESS 



require_once( 'plethora-helper.php' );

/**
 * Plethora class manipulates every theme item module. Contains methods for indexing and loading classes files.
 * 
 * @package Plethora Framework
 * @version 1.0
 * @author Plethora Dev Team
 * @copyright Plethora Themes (c) 2014
 *
 */

class Plethora {

  // Plethora Classes Option
  private $plethora_classes;

  /**
   * Class construct method. It initiates all necessary methods for loading and initiating the theme.
   *
   * @param 
   * @return 
   * @since 1.0
   *
   */
	public function __construct() {

		// Setup Constants & Options

    // Load Theme Constants first! ( always first please! )
    self::load_themeconstants();

    // Set Plethora Framework constants
    self::set_constants();

    // Set Plethora Classes option ( necessary for the features on/off functionality )
    self::set_classes(); 

    // Enqueue Admin Scripts and Styles
    add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue' ));

    // Load Options Framework
    self::load_optionsframework();

    // Load Controllers
    self::load_controllers();

     // Loads Theme Options  
    self::load_theme_options();

    // Load Features
    self::load_features();

     // Loads Theme Functions  
    self::load_theme_functions();
 

  }
  
  /**
   * Theme constants definition  
   *
   * @param 
   * @return 
   * @since 1.0
   *
   */
  public function load_themeconstants() {

    // Load theme related constants file
    if (file_exists( get_template_directory() . '/includes/theme-constants.php' )) { 
 
      require_once( get_template_directory() . '/includes/theme-constants.php' );

    }
  }
  /**
   * Constants definition  
   *
   * @param 
   * @return 
   * @since 1.0
   *
   */
  public function set_constants() {

    $theme_info = wp_get_theme();

    //***** BASIC CONSTANTS *****//

    define( 'PLETHORA_VERSION',       '1.1' );

    # THEME
    define( 'PLETHORA_DOCUMENTATION_URL', 'http://plethorathemes.com/docs/cleanstart/' );

    # PREFIXES
    define( 'PLETHORA_PREFIX',        'plethora' );
    define( 'PLETHORA_META_PREFIX',        'ple-' );

    # OPTION RELATED NAMES
    define( 'PLETHORA_CLASSES_OPTNAME',   PLETHORA_PREFIX .'_classes' );  // used only here

    //***** FRAMEWORK RELATED CONSTANTS *****//

    # URIs
    define( 'THEME_CORE_URI',             plugins_url('plethora-framework/') );                // Plethora framework folder
    define( 'THEME_CORE_ASSETS_URI',      THEME_CORE_URI . '/assets' );         // Plethora framework assets (scripts, styles & images)
    define( 'THEME_CORE_LIBS_URI',        THEME_CORE_URI . '/libs' );           // Plethora framework library folder

    # DIRs
    define( 'THEME_CORE_DIR',             plugin_dir_path(__FILE__)  );                // Plethora framework folder
    define( 'THEME_CORE_ASSETS_DIR',      THEME_CORE_DIR . '/assets' );         // Plethora framework assets (scripts, styles & images)
    define( 'THEME_CORE_LIBS_DIR',        THEME_CORE_DIR . '/libs' );           // Plethora framework library folder
    

    //***** THEME RELATED CONSTANTS *****//
    
    # URIs
    define( 'THEME_URI',                  get_template_directory_uri() );       // Theme folder
    define( 'THEME_INCLUDES_URI',         THEME_URI . '/includes' );            // Theme features folder
    define( 'THEME_PARTIALS_URI',         THEME_INCLUDES_URI . '/partials' );   // Theme template parts folder 
    define( 'THEME_ASSETS_URI',           THEME_URI . '/assets' );              // Theme assets folder
    define( 'CHILD_EXTEND_URI',           get_stylesheet_directory_uri() . '/extend' ); // Child theme extensions folder

    # DIRs
    define( 'THEME_DIR',                  get_template_directory() );           // Theme folder
    define( 'THEME_INCLUDES_DIR',         THEME_DIR . '/includes' );            // Theme features folder
    define( 'THEME_PARTIALS_DIR',         THEME_INCLUDES_DIR . '/partials' );   // Theme template parts folder 
    define( 'THEME_ASSETS_DIR',           THEME_DIR . '/assets' );              // Theme assets folder
    define( 'CHILD_EXTEND_DIR',           get_stylesheet_directory() . '/extend' ); // Child theme extensions folder

    //***** CHECK IF EXTENSION FOLDER EXISTS IN CHILD *****//
    if ( file_exists( CHILD_EXTEND_DIR )) { 

      define( 'CHECK_EXTENSION',            true );   // Enable child theme extension checks

    } else {

      define( 'CHECK_EXTENSION',            false );  // Disable child theme extension checks

    }

  }

  /**
   * Enqueue Admin Scripts and Styles
   *
   * @param 
   * @return 
   * @since 1.0
   *
   */
   static function admin_enqueue() {

        wp_register_style( 'plethora_admin', THEME_CORE_ASSETS_URI . '/admin.css' );
        wp_enqueue_style( 'plethora_admin' );

        wp_register_script( 'admin', THEME_CORE_ASSETS_URI . '/admin.js' );
        wp_enqueue_script('admin');
 
   }



  /**
   * Returns plethora_classes variable
   *
   * @return array 
   * @since 1.0
   *
   */
  private function get_classes() {

      return $this->plethora_classes;

  }

  /**
   * Updates plethora_classes variable  
   *
   * @return array 
   * @since 1.0
   * 
   */
  private function update_classes( $plethora_classes ) {
 
        $this->plethora_classes = $plethora_classes; 
 
  }

  /**
   * Sets plethora_classes variable according to available classes (controllers & feature class files) 
   *
   */
  private function set_classes() {

    // Retrieve plethora classes option..if empty, create just an empty array.
    $plethora_classes = ( get_option( PLETHORA_CLASSES_OPTNAME ) != false) ? get_option( PLETHORA_CLASSES_OPTNAME ) : array();

    // Compare plugin saved version with this one ( non saved in option if previous version was)
    $force_set_classes = false;
    $plethora_version_installed = get_option( 'plethora_version_installed' );
    if (  $plethora_version_installed != PLETHORA_VERSION ) { 

      update_option('plethora_version_installed', PLETHORA_VERSION );
      $force_set_classes = true;

    }
    // If plethora classes option is empty or theme options are updated, the following script will scan the installation for controller/feature files and create the plethora_classes option.
    if ( is_admin() && ( $force_set_classes == true || empty($plethora_classes) || (( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] == 'true' ) && ( isset( $_GET['page'] ) && $_GET['page'] == THEME_OPTIONSPAGE )    ))) {

        //get controller files
        $controllers_folder = THEME_CORE_DIR;
        $controllers_files = Plethora_Helper::get_core_files( $controllers_folder, PLETHORA_PREFIX );
        ksort($controllers_files);

        // Remove plethora-helper.php, as it already loaded
        if (($key = array_search(PLETHORA_PREFIX .'-helper.php', $controllers_files)) !== false) {

          unset($controllers_files[$key]);

        }

        // Fix temporary plethora_classes array
        $plethora_classes_temp = array();

        //Scan and Set Core & Include folder files
        foreach ($controllers_files as $key => $controller_file) {

        
            //fix controller slug
            $controller_slug = str_replace( PLETHORA_PREFIX .'-', '', $controller_file );
            $controller_slug = str_replace( '.php', '', $controller_slug );
            $controller_slug = strtolower( $controller_slug );

            //Controller (key named after class slug)
            $plethora_classes_temp[$controller_slug] = array();

            //Controller => class (name of the class)
            $plethora_classes_temp[$controller_slug]['class'] = ucfirst( PLETHORA_PREFIX ) .'_'. ucfirst( $controller_slug );

            //Controller => file (filename)
            $plethora_classes_temp[$controller_slug]['file']= $controller_file;

            //Controller => features (all the features included under this controller)
            $features_files = Plethora_Helper::get_core_files( THEME_INCLUDES_DIR .'/'. $controller_slug, $controller_slug );

            //Load the controller class
            require_once ( THEME_CORE_DIR .'/'. $controller_file );


            if ( is_array($features_files) ) {

              ksort($features_files);

              // Scan and load feature class files
              foreach ($features_files as $feature_file) {

                //Controller => features => feature slug
                $feature_slug = str_replace( $controller_slug .'-', '', $feature_file );
                $feature_slug = str_replace( '.php', '', $feature_slug );
                $feature_slug = strtolower( $feature_slug );

                //Controller => features => feature slug => class (name of the class)
                $feature_class = ucfirst( PLETHORA_PREFIX ) .'_'. ucfirst( $controller_slug ) .'_'. ucfirst( $feature_slug );
                $plethora_classes_temp[$controller_slug]['features'][$feature_slug]['class'] = $feature_class;

                //Controller => features => feature slug => file (filename)
                $plethora_classes_temp[$controller_slug]['features'][$feature_slug]['file'] = $feature_file;

                //Controller => features => feature slug => feature_options (options included on every feature class)

                  //Load the feature file 
                  require_once ( THEME_INCLUDES_DIR .'/'. $controller_slug .'/'. $feature_file );

                  // If class and 'get_feature_options' method exist...get them!
                  if ( class_exists($feature_class) && method_exists( $feature_class, 'get_feature_options' )) { 

                     // Instantiate the class
                     $class_instance = new $feature_class;

                     // Get feature information array, using the classic 'get_feature_options'
                     $feature_options = $class_instance->get_feature_options();

                  } else { 

                      // If 'get_feature_options' method is not included in file, set default feature options 
                     $feature_options = array (
                     'switchable' => 0,
                     'version' => '1.0',
                     );

                  }  

                // Update the temporary plethora_class array
                $plethora_classes_temp[$controller_slug]['features'][$feature_slug]['feature_options'] = $feature_options;
    
              }
            }
          } 
         // Replace temporary plethora_class array & update plethora_classes db option
         $plethora_classes = $plethora_classes_temp;
         $update = update_option(PLETHORA_CLASSES_OPTNAME, $plethora_classes );

         
         // Refreshing theme options page in order feature activation/deactivation options to take effect ( don't do it if this refresh comes out of the update trigger )
         if ( ! $force_set_classes ) { 
           header("Location: ". get_admin_url() ."admin.php?page=". THEME_OPTIONSPAGE ."&tab=0&plethora-updated=true");
         }

    // If not in admin, just set the plethora_classes variable         
    } 

  $this->update_classes($plethora_classes);
}

  /**
   * Loads Redux Options framework. Any customizations must be placed here.
   *
   * @since 1.0
   *
   */
  private function load_optionsframework() {

    if ( !class_exists( 'ReduxFramework' ) && file_exists( THEME_CORE_LIBS_DIR . '/ReduxFramework/ReduxCore/framework.php' ) ) {
      
      require_once( THEME_CORE_LIBS_DIR . '/ReduxFramework/ReduxCore/framework.php' );

    }    


  }

  /**
   * Loads controller classes. Every controller class manages a different Plethora objects group.
   *
   * @since 1.0
   *
   */
  private function load_controllers() {

    //load plethora classes index and check if is array
    $controllers = $this->get_classes();
    if ( !is_array($controllers) ) { return; }

    // Load controller files
    foreach ( $controllers as $controller=>$controller_options ) { 

      // Fix feature's slug NAME
      $controller_slug = $controller;
      // Fix feature's class name
      $controller_class = ( array_key_exists( 'class', $controllers[$controller] ) ? $controllers[$controller]['class'] : NULL );  
      // Fix feature's class name
      $controller_file = ( array_key_exists( 'file', $controllers[$controller] ) ? ( file_exists(THEME_CORE_DIR .'/'. $controllers[$controller]['file']) ? THEME_CORE_DIR .'/'. $controllers[$controller]['file'] : NULL )  : NULL );

      if ( isset( $controller_slug ) && isset( $controller_class ) && isset( $controller_file )) {

          if ( !class_exists( $controller_class )) {

            // load controller class file
            require_once( $controller_file );

          };

      } 
    }
  }


  /** 
   * Loads and initiates object groups classes (i.e. post types / taxonomy classes) of the given controller.
   *
   * @param $controller_slug (string)
   * @return bool
   * @since 1.0
   *
   */
  private function load_features( ) {

    //load plethora classes index and check if is array
    $controllers = $this->get_classes();
    if ( !is_array($controllers) ) { return; }

    // ATTENTION...we need unset metaboxes, as it is already loaded by controller itself
    if ( array_key_exists('metabox', $controllers)) {

        unset($controllers['metabox']);
    }         


    // Get theme options, in order to check activated/deactivated features
    $plethora_settings = get_option( THEME_OPTVAR );

    foreach ( $controllers as $controller=>$controller_options ) { 

      // feature's slug 
      $controller_slug = $controller;
      // feature's class name
      $controller_class = ( array_key_exists( 'class', $controllers[$controller] ) ? $controllers[$controller]['class'] : NULL );  
      // feature's filename
      $controller_file = ( array_key_exists( 'file', $controllers[$controller] ) ? ( file_exists(THEME_CORE_DIR .'/'. $controllers[$controller]['file']) ? THEME_CORE_DIR .'/'. $controllers[$controller]['file'] : NULL )  : NULL );

      if ( class_exists( $controller_class ) && isset( $controller_slug ) && isset( $controller_class ) && isset( $controller_file )) {

        // fix features folder value according to controller's slug name
        $features_folder  = ( is_dir( THEME_INCLUDES_DIR .'/'. $controller_slug ) ? THEME_INCLUDES_DIR .'/'. $controller_slug : NULL );

        $features = ( array_key_exists( 'features', $controllers[$controller_slug] )  ? $controllers[$controller_slug]['features'] : NULL );

        // if everything is here, then proceed
        if ( isset( $features_folder ) && isset( $features ) ) {

          foreach ( $features as $feature_slug => $feature_settings ) {

            // Fix features's class name
            $feature_class = $feature_settings['class'];

            // Fix features's class file name
            $feature_file = $features_folder .'/'. $feature_settings['file']; 

            //Check if feature is switchable ( switchable: allowed to be activated/deactivated on theme options panel )
            $feature_switchable = $this->get_feature_option( $controller_slug, $feature_slug, 'switchable' );

            //Check theme settings to get activation/deactivation status value
            $feature_status_optionname = ''. $controller_slug .'-'. $feature_slug .'-status';
            $feature_status = isset($plethora_settings[$feature_status_optionname]) ? $plethora_settings[$feature_status_optionname] : true;

            // Decide whether to load the feature
            if ($feature_switchable) { 

                if ($feature_status) { 

                      $feature_load = true;
                     // echo $feature_slug. "switchable:true | feature_load:true<br/>";
                } else { 

                      $feature_load = false;
                    //  echo $feature_slug. "switchable:true | feature_load:false<br/>";
                }

            } else {
                    //  echo $feature_slug. "switchable:false<br/>";

                $feature_load = true;
            }


            // proceed if class is not already loaded, the filename is valid
            if ( file_exists( $feature_file ) && $feature_load ) {

                require_once ( $feature_file );

                // repeat check for class and initiate
                if ( class_exists( $feature_class ) ) { 

                   $feauture_inst = new $feature_class;

                }
            }
          }
        } 
      }
    }
  }

  /** 
   * Set up all theme depended parameters
   * Also, theme-functions.php will replace the functions.php for devs who want to extend Plethora core
   *
   * @return bool
   * @since 1.0
   *
   */
  private function load_theme_options() { 


    // Load theme options class
    if (file_exists( get_template_directory() . '/includes/theme-options.php' )) { 
 
      require_once( get_template_directory() . '/includes/theme-options.php' );

    }

  }

  /** 
   * Set up all theme functions
   *
   * @return bool
   * @since 1.0
   *
   */
  private function load_theme_functions() { 


    // Load theme functions class
    if (file_exists( get_template_directory() . '/includes/theme-functions.php' )) { 
 
      require_once( get_template_directory() . '/includes/theme-functions.php' );

    }

  }

  /** 
   * Returns feature option value
   *
   * @param $controller_slug (string), $feature_slug (string), $feature_options (array)
   * @return bool
   * @since 1.0
   *
   */
  private function get_feature_option( $controller_slug, $feature_slug, $feature_option ) {

    //get plethora classes options
    $plethora_classes = $this->get_classes();

    //feature record
    if ( array_key_exists( $feature_option, $plethora_classes[$controller_slug]['features'][$feature_slug]['feature_options'] ) && isset( $feature_option )) { 
        $option_value = $plethora_classes[$controller_slug]['features'][$feature_slug]['feature_options'][$feature_option];
      //print_r($plethora_classes[$controller_slug]['features'][$feature_slug]['feature_options']);
      return $option_value;

    } else { 
      return false;
    }

  }    
}